/*==================================================================
 Program: OC_Expt.do
 Edited:  February 2019
 Purpose: Analyzes data from mileage experimental belief survey with Firm B.
===================================================================*/


/*==================================================================
PARTS OF THE FILE:
1. SUMMARY STATISTICS AND RANDOMIZATION CHECK
2. MAIN REGRESSIONS: Impact of Incentive & Information on Beliefs
===================================================================*/

clear
set more off
qui do "../Expt/zz_globals_msurvey.do"

/*==================================================================
1. SUMMARY STATISTICS AND RANDOMIZATION CHECK
==================================================================*/
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear
collapse incent debiasing hi, by(id)
tab incent
tab debiasing incent
tab debiasing
tab hi incent


/*================================================
Compare workers by incentive treatment status.
TOP OF TABLE B1.
=================================================*/
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear
global FixedVars "female age experience $GeogDum_SS"
collapse $FixedVars incent, by(id)

* Top of Table B1
matrix SS_Expt = [0,0,0]
foreach yX of global FixedVars {
	ttest `yX', by(incent)
	matrix SS_Expt = [SS_Expt\ round(r(mu_1),.01), round(r(mu_2),.01), round(r(p),.01)]
}
count if incent==0
scalar N_Expt_NoIncent = r(N)
count if incent==1
scalar N_Expt_Incent = r(N)
matrix SS_Expt = [SS_Expt\N_Expt_NoIncent, N_Expt_Incent,0]
scalar zz = rowsof(SS_Expt)
matrix SS_Expt = SS_Expt[2..zz,1..3]
matrix rowname SS_Expt = Female Age Experience West Midwest Northeast South NumberOfDrivers
matrix colnames SS_Expt = NoIncentive TenDollarIncentive TTest-PVal
outtable using "$obpath/Tab-Expt-SumStats-Incent_$spec", mat(SS_Expt) nobox center replace

* Calculate the amount of missingness
matrix rownames H = Female Age Experience West Midwest Northeast South
matrix H = J(7,1,0)
local Counter = 0
foreach yX of global FixedVars {
	local Counter = `Counter'+1
	count if mi(`yX')
	matrix H[`Counter',1] = r(N)
}
outtable using "$obpath/Tab-Expt-SumStats-Missing_$spec", mat(H) nobox center replace


/*================================================
Next, compare workers by the debiasing treatment.
BOTTOM OF TABLE B1.
=================================================*/
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear

collapse female age experience incent debiasing hi $GeogDum_SS, by(id)

* Incent50 measures there is a driver who has at least one week in the high-incentive group
gen incent50= (hi>0)
assert incent50==0 | incent50==1

matrix H = J(8,6,0)

matrix rownames H = Female Age Experience West Midwest Northeast South Number_of_drivers
matrix colnames H = Debiasing No_Debiasing 50_Incentive ttest_1vs2 ttest_1vs3 ttest_2vs3

gen group = .
replace group = 1 if debiasing==1
replace group = 2 if debiasing==0
replace group = 3 if incent50==1

* Get counts of which variables are missing.
foreach yX of global FixedVars{
	count if mi(`yX') & ~mi(group)
}

local Counter = 0
foreach yX of global FixedVars{
	local Counter = `Counter'+1
	mean `yX', over(group)
	matrix J=e(b)
	matrix H[`Counter',1]=J[1,1]
	matrix H[`Counter',2]=J[1,2]
	matrix H[`Counter',3]=J[1,3]	
	ttest `yX' if group==1 | group==2, by(group)	
	matrix H[`Counter',4]=r(p)
	ttest `yX' if group==1 | group==3, by(group)	
	matrix H[`Counter',5]=r(p)
	ttest `yX' if group==2 | group==3, by(group)	
	matrix H[`Counter',6]=r(p)
}
forvalues iX=1/3{
	count if group==`iX'
	matrix H[8,`iX']=r(N)
}
matrix H1 = H
forvalues iX=1/7{
	forvalues kX=1/6{
		matrix H1[`iX',`kX']=round(H[`iX',`kX'],.01)
	}
}
outtable using "$obpath/Tab-Expt-SumStats-S2_$spec", mat(H1) nobox replace center



/*================================================
How many weeks per driver in Stage I of the experiment?
=================================================*/

set more off
use "$Tmp_E/Expt.dta", clear

* Restrict to drivers who ever make it to Stage II of the Experiment
by id: egen max_postdebiasing1 = max(postdebiasing1)
gen bigstakesexpt = ~mi(stakesexpt)
by id: egen max_bigstakesexpt = max(bigstakesexpt)
keep if max_postdebiasing1==1 | max_bigstakesexpt==1

* Count up the weeks in Stage I of the experiment
keep if postdebiasing1==0 & mi(stakesexpt)
gen one = 1
by id: egen num_weeks_stage1 = sum(one)



/*================================================
ATTRITION OVER THE EXPERIMENT
Appendix Footnote on differential attrition over experiment.
=================================================*/
set more off
use "$Tmp_E/Expt.dta", clear
gen one=1
by id: egen num_weeks = sum(one)
forvalues iX=2/6{
	gen num_weeks_more`iX' = (num_weeks>=`iX')
	reg num_weeks_more`iX' incent if week==1
}


/*==================================================================
2. MAIN REGRESSIONS: Impact of Incentive & Information on Beliefs
==================================================================*/

/*================================================
TABLE B2. Do incentives for accuracy or information 
reduce worker overconfidence?

We focus on miles predictions, but also perform
results for earnings predictions.
=================================================*/
set more off
foreach yX in milesp earningsp{
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear
/*
"Incent_now" is dummy for whether driver has $10 incentive in given week.
"Hi" ris dummy for whether a driver has the $50 incentive in a given week.
*/

* Trim `yX' at the 5th and 95th percentiles, leaving middle 90th percent of data.
keep if tail`yX'90==0

reg `yX' incent_now hi postdebiasing1_debias postdebiasing1 debiasing_assign $BaseControls, cluster(id)
* Get average mileage overconfidence in column 1 sample
	sum overconf if e(sample)==1
	capture drop zz1 zz
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = mean(zz1)
	test incent_now hi
	outreg2 incent_now hi postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-`yX'_$spec", $OR2_mdv_clust_F replace
* For column 1, also include confidence intervals on "incent_now" and "hi".
	scalar lb_incent_now = _b[incent_now]-1.96*_se[incent_now]	
	scalar ub_incent_now = _b[incent_now]+1.96*_se[incent_now]	
	scalar lb_hi = _b[hi]-1.96*_se[hi]	
	scalar ub_hi = _b[hi]+1.96*_se[hi]	
	matrix CIs_95Percent_Incentives = [round(lb_incent_now,1),round(ub_incent_now,1)\round(lb_hi,1),round(ub_hi,1)]
	matrix rowname CIs_95Percent_Incentives = 10DollarIncentive 50DollarIncentive
	matrix colnames CIs_95Percent_Incentives = LowerBound UpperBound
	outtable using "$obpath/Tab-Expt-Incent95CIs-`yX'_$spec", mat(CIs_95Percent_Incentives) nobox center replace
reg `yX' incent_now hi postdebiasing1_debias postdebiasing1 debiasing_assign $BaseControls $B_Demogs, cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = mean(zz1)
	test incent_now hi
	outreg2 incent_now hi postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-`yX'_$spec", $OR2_mdv_clust_F append
reg `yX' incent_now hi debiasing_wk0-debiasing_wk3 debiasing_wk4to6 postdebiasing1 debiasing_assign $BaseControls $B_Demogs, cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = mean(zz1)
	test incent_now hi
	outreg2 incent_now hi debiasing_wk0-debiasing_wk3 debiasing_wk4to6 using "$obpath/Tab-ExptsFirmB-`yX'_$spec", $OR2_mdv_clust_F append
}


** Different impacts depending on the incentive faced	
/*
Appendix Footnote regarding experimental demand effect and on how
predictions vary based on whether there's an incentive or not.
*/
set more off
reg milesp incent_now hi postdebiasing1_debias postdebiasing1 debiasing_assign $BaseControls $B_Demogs if incent==1, cluster(id)
	outreg2 postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-DebiasingByIncent_$spec", $OR2 replace
reg milesp incent_now hi postdebiasing1_debias postdebiasing1 debiasing_assign $BaseControls $B_Demogs if incent==0, cluster(id)
	outreg2 postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-DebiasingByIncent_$spec", $OR2 append

	
/*================================================
Big Incentives Only.
This is mentioned in a footnote at the end of
Appendix B1.
=================================================*/	
	
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear

gen bigincent_dummy = ~mi(bigincent)
by id: egen has_bigincent = max(bigincent_dummy) 
by id: egen has_hi = max(hi)

gen week_int = wofd(idate)
format %td week_int
areg milesp hi i.daysnotwork1 i.week_int if tailmilesp90==0 & has_hi==1, cluster(id) absorb(id)
	outreg2 hi using "$obpath/Tab-ExptsFirmB-HiOnly_$spec", $OR2 replace

	
/*================================================
APPENDIX TABLE B3: Regression Analysis on Other Outcomes
================================================*/
* Add the below to deal with outreg2 saying files are read-only
winexec taskkill /F /IM Notepad.exe /T

set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear
collapse quitbyend debiasing incent experience tenure_by_start_of_rct (max) debiasweek, by(id)
reg quitbyend debiasing incent experience tenure_by_start_of_rct if (debiasing==0 | debiasing==1) & (debiasweek>=0 & debiasweek!=.), cluster(id)
	outreg2 debiasing incent using "$obpath/Debias_OtherOutcomes_$spec", $OR2_nodec dec(2) append
	sum quitbyend if debiasing==0 & e(sample)==1	
use "$Tmp_E/Expt.dta", clear
oprobit searchintention1 debiasing incent experience i.week i.daysnotwork1, cluster(id)
	*outreg2 debiasing incent using "$obpath/Debias_OtherOutcomes_$spec", $OR2_nodec dec(2) replace
oprobit jobsatis1 debiasing incent experience i.week i.daysnotwork1, cluster(id)
	*outreg2 debiasing incent using "$obpath/Debias_OtherOutcomes_$spec", $OR2_nodec dec(2) append
		
		
/*================================================	
APP. TABLE B5: ROBUSTNESS CHECK ON IMPACT OF DEBIASING 
Look at week by week impacts of debiasing.
=================================================*/			
foreach yX in milesp debiasweekchange{
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear
keep if tail`yX'90==0
reg `yX' postdebiasing1_debias milesgive2 incent_now $BaseControls $B_Demogs if (debiasweek>=0 & debiasweek<=6), cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = mean(zz1)
	outreg2 postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-Combo-DebiasSamp-`yX'_$spec", $OR2_mdv_clust replace
forvalues iX=0/3{
	reg `yX' postdebiasing1_debias milesgive2 incent_now $BaseControls $B_Demogs if debiasweek==`iX', cluster(id)
		capture drop zz1 zz
		egen zz1 = mean(`yX') if e(sample)==1
		egen zz = mean(zz1)
		outreg2 postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-Combo-DebiasSamp-`yX'_$spec", $OR2_mdv_clust append
}
reg `yX' postdebiasing1_debias milesgive2 incent_now $BaseControls $B_Demogs if (debiasweek==4 | debiasweek==5 | debiasweek==6), cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = mean(zz1)
	outreg2 postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-Combo-DebiasSamp-`yX'_$spec", $OR2_mdv_clust append	
}

		

/*================================================
ROBUSTNESS CHECK: LOOK AT OLD WORDING		
=================================================*/			
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear
keep if tailmilesp90==0
foreach yX in 1 0 {
	reg milesp incent_now hi postdebiasing1_debias postdebiasing1 debiasing_assign $BaseControls if old_wording==`yX', cluster(id)
}


	
/*==================================================================
APPENDIX TABLE B4.
RESTRICT TO WEEKS BEFORE DEBIASING.
===================================================================*/	

set more off
qui do "$E_Path/zz_globals_msurvey.do"
foreach yX in milesp overconf{
use "$Tmp_E/Expt.dta", clear
drop if (debiasweek>=0 & debiasweek<=6) | hi==1
keep if tail`yX'90==0
reg `yX' incent_now  $BaseControls, cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = mean(zz1)
	outreg2 incent_now hi postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-Combo-StageI-$spec", $OR2_mdv_clust append
reg `yX' incent_now  $BaseControls $B_Demogs, cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(`yX') if e(sample)==1
	egen zz = mean(zz1)
	outreg2 incent_now hi postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-Combo-StageI-$spec", $OR2_mdv_clust append
}


	
/*==================================================================
APPENDIX TABLE E5.
DO PRODUCTIVITY BELIEFS PREDICT PRODUCTIVITY? 
And how does predictiveness vary with incentives?
===================================================================*/	

* Add the below to deal with outreg2 saying files are read-only
winexec taskkill /F /IM Notepad.exe /T	
	
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt_WithPredictMilesVars.dta", clear
reg hmiles L.hpmiles $Cont_BPP, cluster(id)
	outreg2 L.hpmiles using "$obpath/Table-PredictProd-FirmB-$spec", $OR2 replace
reg hmiles L.hpmiles $Cont_BPP $B_Demogs, cluster(id)
	outreg2 L.hpmiles using "$obpath/Table-PredictProd-FirmB-$spec", $OR2 append
reg hmiles L.hpmiles incent_now incent_nowXLphmiles hi hiXLphmiles $Cont_BPP $B_Demogs, cluster(id)
	outreg2 L.hpmiles incent_now incent_nowXLphmiles hi hiXLphmiles using "$obpath/Table-PredictProd-FirmB-$spec", $OR2 append
reg hmiles L.hpmiles L.hmmiles $Cont_BPP, cluster(id)
	outreg2 L.hpmiles L.hmmiles using "$obpath/Table-PredictProd-FirmB-$spec", $OR2 append
reg hmiles L.hpmiles L.hmmiles $Cont_BPP $B_Demogs, cluster(id)
	outreg2 L.hpmiles L.hmmiles using "$obpath/Table-PredictProd-FirmB-$spec", $OR2 append
areg hmiles L.hpmiles $Cont_BPP, absorb(id) cluster(id)
	outreg2 L.hpmiles using "$obpath/Table-PredictProd-FirmB-$spec", $OR2 append


/*================================================
Robustness Check: Do incentives reduce large differences?
=================================================*/	
set more off
qui do "$E_Path/zz_globals_msurvey.do"
use "$Tmp_E/Expt.dta", clear
reg quadiff incent hi postdebiasing1_debias postdebiasing1 debiasing_assign $BaseControls if tailquadiff98==0 , cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(quadiff) if e(sample)==1
	egen zz = mean(zz1)
	test incent hi
	outreg2 incent hi postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-Quadiff", $OR2_mdv_clust_F replace
reg quadiff incent hi postdebiasing1_debias postdebiasing1 debiasing_assign experience $BaseControls $B_Demogs if tailquadiff98==0 , cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(quadiff) if e(sample)==1
	egen zz = mean(zz1)
	test incent hi
	outreg2 incent hi postdebiasing1_debias using "$obpath/Tab-ExptsFirmB-Quadiff", $OR2_mdv_clust_F append
reg quadiff incent hi debiasing_wk0-debiasing_wk3 debiasing_wk4to6 postdebiasing1 debiasing_assign experience $BaseControls $B_Demogs if tailquadiff98==0 , cluster(id)
	capture drop zz1 zz
	egen zz1 = mean(quadiff) if e(sample)==1
	egen zz = mean(zz1)
	test incent hi
	outreg2 incent hi debiasing_wk0-debiasing_wk3 debiasing_wk4to6 using "$obpath/Tab-ExptsFirmB-Quadiff", $OR2_mdv_clust_F append


