/*==================================================================
Program: CPS_Clean.do
Edited:  January 2019
Purpose: Cleans CPS data for auxiliary use in Overconfidence paper.
==================================================================*/

clear
clear matrix
set more off
qui do "$fullpath/zz_globals_panel.do"

/*==================================================================
CLEAN CPS DATA
==================================================================*/
use "$Tmp/CPS2007.dta", clear
gen male = (sex==1)
/*

EDUC99 reports the respondent's highest level of educational 
attainment. Respondents without high school diplomas were to 
indicate the highest school grade they had completed, while 
those with high school diplomas were to indicate the highest 
diploma or degree they had obtained.

The CPS followed the pattern set by the 1990 census in adopting 
this mode of recording educational attainment. Prior to 1992, 
information was collected about the highest grade of school 
attended and completed; this can be found in HIGRADE. Researchers 
who wish to study educational attainment both before and after 
1992 should use the EDUC variable.

. tab educ99

           Educational attainment, 1990 |      Freq.     Percent        Cum.
----------------------------------------+-----------------------------------
                                    NIU |     50,685       24.53       24.53
                    No school completed |        602        0.29       24.82
                          1st-4th grade |      1,408        0.68       25.50
                          5th-8th grade |      7,948        3.85       29.35
                              9th grade |      6,192        3.00       32.34
                             10th grade |      7,009        3.39       35.74
                             11th grade |      7,245        3.51       39.24
                 12th grade, no diploma |      2,713        1.31       40.55
           High school graduate, or GED |     45,258       21.90       62.46
                Some college, no degree |     27,448       13.28       75.74
 Associate degree, occupational program |      6,561        3.18       78.91
     Associate degree, academic program |      5,803        2.81       81.72
                       Bachelors degree |     25,130       12.16       93.88
                         Masters degree |      8,953        4.33       98.22
                    Professional degree |      2,024        0.98       99.20
                       Doctorate degree |      1,660        0.80      100.00
----------------------------------------+-----------------------------------
                                  Total |    206,639      100.00
. count if educ99==10
  45,258
*/
count if educ99==10
assert r(N)==45258
assert ~mi(educ99)
gen educ_hs = (educ99==10)  
label variable educ_hs "High school graduate" 
  

/*
. tab educrec

 Educational attainment |
                 recode |      Freq.     Percent        Cum.
------------------------+-----------------------------------
                    NIU |     50,685       24.53       24.53
      None or preschool |        602        0.29       24.82
   Grades 1, 2, 3, or 4 |      1,408        0.68       25.50
   Grades 5, 6, 7, or 8 |      7,948        3.85       29.35
                Grade 9 |      6,192        3.00       32.34
               Grade 10 |      7,009        3.39       35.74
               Grade 11 |      7,245        3.51       39.24
               Grade 12 |     47,971       23.21       62.46
1 to 3 years of college |     39,812       19.27       81.72
    4+ years of college |     37,767       18.28      100.00
------------------------+-----------------------------------
                  Total |    206,639      100.00  
*/




tab fullpart
/*
FULLPART indicates whether respondents who were employed during the 
previous calendar year worked full-time or part-time. Full-time work is 
defined as thirty-five hours a week or more. Beginning in 1976, more 
detailed information on hours worked during the previous year is 
available in UHRSWORKLY.

. tab fullpart, mi

Worked full |
    or part |
  time last |
       year |      Freq.     Percent        Cum.
------------+-----------------------------------
        NIU |     99,806       48.30       48.30
  Full-time |     85,464       41.36       89.66
  Part-time |     21,369       10.34      100.00
------------+-----------------------------------
      Total |    206,639      100.00
*/
count if fullpart==1
assert r(N)==85464
gen full_time = (fullpart==1)
label variable full_time "Worker is full time"

* Age is a whole number
assert mod(age,1)==0

* Male high-school gradus between 30-40
keep if educ_hs==1 & age>=30 & age<=40 & full_time==1 & male==1

* Generate dummy for working in trucking
gen occ_trucking = (occ==9130)
label variable occ_trucking "Occupation is trucking"

save "$Tmp/CPS2007_CompSample.dta", replace


/*==================================================================
CREATE POOLED DATASET
==================================================================*/
set more off
use "$Tmp/Panel_Cleaned.dta", clear
collapse opp_income, by(DrvID)
assert mod(opp_income,1)==0
gen nhp=1
save "$Tmp/NHP_OppIncome.dta", replace

/*
INCWAGE indicates each respondent's total pre-tax wage and salary income--
that is, money received as an employee--for the previous calendar year. Amounts 
are expressed as they were reported to the interviewer; users must adjust 
for inflation using Consumer Price Index adjustment factors.
*/

use "$Tmp/CPS2007_CompSample.dta", clear
keep incwage occ_trucking age
gen nhp=0
gen opp_income = .
replace opp_income = 5 if incwage>=0 & incwage<=10000
replace opp_income = 15 if incwage>10000 & incwage<=20000
replace opp_income = 25 if incwage>20000 & incwage<=30000
replace opp_income = 35 if incwage>30000 & incwage<=40000
replace opp_income = 45 if incwage>40000 & incwage<=50000
replace opp_income = 55 if incwage>50000 & incwage<=60000
replace opp_income = 65 if incwage>60000 & incwage<=70000
replace opp_income = 75 if incwage>70000 & ~mi(incwage)
save "$Tmp/CPS2007_OppIncome.dta", replace


use "$Tmp/NHP_OppIncome.dta", clear
append using "$Tmp/CPS2007_OppIncome.dta"
drop DrvID
order nhp occ_trucking opp_income
label variable opp_income "Income (perceived in NHP; actual in CPS)"
label define inc_range_vals 5 "0-10" 15 "10-20" 25 "20-30" 35 "30-40" 45 "40-50" 55 "50-60" 65 "60-70" 75 "70+"
label values opp_income inc_range_vals

gen group = 1 if nhp==1
replace group = 2 if nhp==0 & age==35
replace group = 3 if nhp==0 & occ_trucking==1
label variable group "Group in three-way comparison"
label define group_vals 1 "Exp Income" 2 "CPS" 3 "CPS Truckers"
label values group group_vals

cf _all using "$Tmp/Pooled_OppIncome.dta"
save "$Tmp/Pooled_OppIncome.dta", replace



