/*==================================================================
Program: OC_Panel.do
Edited:  January 2019
Purpose: Analyzes Firm A subjective beliefs for paper on overconfidence.

Main Results:
1. Summary Stats (Table 1)
2. Dynamics of Beliefs and Productivity (Figure 1)
3. Do beliefs predict productivity? (Table 2)
4. Beliefs and quitting (Table 3 and Table E1)

Appendix Materials:
5. Response to belief survey (Table A1, Figure E1)
6. More on beliefs (Figure E2, Figure E3, Table E4, Figure E4)
7. Robustness on beliefs and quitting (Tables E2-E3)

8. Misc Claims in Text:
~ Average income of worker similar to ours in 2007 CPS.
~ Exit survey response mostly uncorrelated with unobservables.
~ Share moving to different jobs.
==================================================================*/

clear
clear matrix
set more off
qui do "../zz_globals_panel.do"


/*==================================================================
1. SUMMARY STATISTICS: TABLE 1 AND OTHER STATISTICS
==================================================================*/

* Add the below to deal with outreg2 saying files are read-only
winexec taskkill /F /IM Notepad.exe /T

/*================================================
Demographics:
~ Means within the overall New Hire Panel (Panel A of Table 1)
~ Share of people with missing demogs (NOT A PAPER TABLE).
================================================*/

* Calculate means
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned.dta", clear
global VarList "GenFemaleVsAll RaceAfAm RaceHisp AgeYr MS_MarriedVsAll kids schooling crscore crinsufhis"
matrix SS_FullData = [0]
foreach yX of global VarList {
	sum `yX' if firstwk==1
	matrix SS_FullData = [SS_FullData\ round(r(mean),.01)]
}
matrix list SS_FullData
scalar zz = rowsof(SS_FullData)
matrix SS_FullData = SS_FullData[2..zz,1]
matrix rowname SS_FullData = Female Black Hispanic Age Married Number_of_kids Years_of_Schooling Credit_Score No_Credit_Score
outtable using "$obpath/Tab-SSDemogs-$spec", mat(SS_FullData) nobox replace center

* Get share with missing data
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned.dta", clear
global FixedVarsMissing "GenUnknown RaceUnknown MS_Unknown"
matrix SSMissing_FullData = [0]
foreach yX of global FixedVarsMissing {
	sum `yX' if firstwk==1
	matrix SSMissing_FullData = [SSMissing_FullData\ round(r(mean),.001)]
}
matrix list SSMissing_FullData
scalar zz = rowsof(SSMissing_FullData)
matrix SSMissing_FullData = SSMissing_FullData[2..zz,1]
matrix rowname SSMissing_FullData = GenMissing RaceMissing MarriedMissing
outtable using "$obpath/Tab-DemMissing-$spec", mat(SSMissing_FullData) nobox replace center


/*================================================
Summary Stats on Productiity and Productivity Beliefs
================================================*/

***** PANEL B OF TABLE 1
* Miles and Miles Beliefs Summary Stats for the Full Sample
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned.dta", clear
sum miles if miles>0, detail
	matrix SS_MilesPmiles = [round(r(p10),1),round(r(p25),1),round(r(p50),1),round(r(p75),1),round(r(p90),1),round(r(mean),1)]
sum pmiles, detail
	matrix SS_MilesPmiles = [SS_MilesPmiles \ round(r(p10),1),round(r(p25),1),round(r(p50),1),round(r(p75),1),round(r(p90),1),round(r(mean),1)]
* Miles and Miles Beliefs Summary Stats for Estimation Sample	
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned.dta", clear
keep if est_sample==1
sum miles if miles>0, detail	
	matrix SS_MilesPmiles = [SS_MilesPmiles \ round(r(p10),1),round(r(p25),1),round(r(p50),1),round(r(p75),1),round(r(p90),1),round(r(mean),1)]
sum pmiles, detail
	matrix SS_MilesPmiles = [SS_MilesPmiles \ round(r(p10),1),round(r(p25),1),round(r(p50),1),round(r(p75),1),round(r(p90),1),round(r(mean),1)]	
* Output the table.	
matrix SS_MilesPmiles = SS_MilesPmiles'
matrix rowname SS_MilesPmiles = 10\% 25\% 70\% 75\% 90\% Mean
matrix colnames SS_MilesPmiles = Miles MilesBeliefs Miles MilesBeliefs
outtable using "$obpath_main/Tab-SumStats-Panel-MilesPmiles_$spec", mat(SS_MilesPmiles) nobox center replace

***** OTHER SUMMARY STATS FOR ESTIMATION SAMPLE

* Overall response rate
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned.dta", clear
sum respond
	matrix SS_ResponseRate = [round(r(mean),.01)]
* Response rate in weeks where driver has non-zero miles---> YIELDS 28% RESPONSE RATE.
sum respond if miles>0 & ~mi(miles)
	matrix SS_ResponseRate = [SS_ResponseRate \ round(r(mean),.01)]
outtable using "$obpath_main/Tab-SumStats-Panel-ResponseRate_$spec", mat(SS_ResponseRate) nobox center replace	


* In what share of weeks do beliefs exceed miles?
use "$Tmp/Panel_Cleaned.dta", clear
gen overpredict = (pmiles>miles_p1) if ~mi(miles_p1) & miles_p1>0 & ~mi(pmiles)
gen underpredict = (pmiles<miles_p1) if ~mi(miles_p1) & miles_p1>0 & ~mi(pmiles)
sum overpredict underpredict

* Day of the survey.
use "$Tmp/Panel_Cleaned.dta", clear
tab survey_day


/*==================================================================
2. DYNAMICS OF BELIEFS AND PRODUCTIVITY
==================================================================*/
			
/*================================================
FIGURE 1: BASELINE FIGURE

kX = Statistic of interest
	~ foreach kX in mean median {

zX = Tenure restriction for making graph
	~ foreach zX in 75 100 {
================================================*/	
* (3a) Means and (3b) Medians
set more off	
foreach kX in mean median {
use "$Tmp/Panel_Cleaned.dta", clear
keep if fig_sample==1
collapse (`kX') miles pmiles, by(week)
twoway (lpolyci miles week, bw(5)) (lpolyci pmiles week, bw(7) lpattern(-)) if week>=6 & week<=110, ///
	xtitle(Weeks of tenure) ytitle(Miles per week) ///
	legend(lab(2 "Miles") lab(4 "Mile beliefs")) graphr(fc(white))
graph export "$FigPath/Fig-MilesPmiles-`kX'-$spec.pdf", as(pdf) replace	
gen overconf = pmiles - miles
sum overconf if week>=6 & week<=15
sum overconf if week>=101 & week<=110
}

* (3c): Means, Restrict to Workers who Stay at Least 75 Weeks
* (3d): Medians, Restrict to Workers who Stay>=75 Weeks and Who Respond to Survey.
* Also, make the same picture for 100 weeks.
set more off
foreach zX in 75 100 {
foreach kX in mean median {	
use "$Tmp/Panel_Cleaned.dta", clear
keep if fig_sample==1
keep if tenure>=`zX'
gen V1 = "median"
drop if ever_respond==0 & V1=="`kX'"
collapse (`kX') miles pmiles, by(week)
twoway (lpolyci miles week, bw(5)) (lpolyci pmiles week, bw(7) lpattern(-)) if week>=6 & week<=110, ///
	xtitle(Weeks of tenure) ytitle(Miles per week) ///
	legend(lab(2 "Miles") lab(4 "Mile beliefs")) graphr(fc(white))
graph export "$FigPath/Fig-MilesPmiles-`kX'Tenure`zX'-$spec.pdf", as(pdf) replace	
gen overconf = pmiles - miles
sum overconf if week>=6 & week<=15
sum overconf if week>=101 & week<=110
}
}

	
/*==================================================================
3. DO BELIEFS PREDICT PRODUCTIVITY? (Table 2)

zX = Sample restriction. 
	~ foreach zX in all0 { 
	~ foreach zX in all0 hadabp hadabp_hadsalary team multiple500{

We use "all0" for Table 3. The other robustness is:
no Had_ABP, no Had_ABP/Had_Salary, no team, no multiples of 500.
==================================================================*/	
	
* Add the below to deal with outreg2 saying files are read-only
winexec taskkill /F /IM Notepad.exe /T		
		
set more off
qui do "$fullpath/zz_globals_panel.do"	
foreach zX in all0 {
use "$Tmp/Panel_Cleaned.dta", clear
tsset DrvID week
keep if `zX'==0
reg hmiles L.hpmiles $TenureVars_PP, cluster(DrvID)
	outreg2 L.hpmiles using "$obpath/Tab-PredProd-Drop_`zX'-$spec", $OR2_D3 replace
reg hmiles L.hpmiles $FullControls_PP, cluster(DrvID)	
	outreg2 L.hpmiles using "$obpath/Tab-PredProd-Drop_`zX'-$spec", $OR2_D3 append
reg hmiles L.hpmiles L.hmmiles $TenureVars_PP, cluster(DrvID)
	outreg2 L.hpmiles L.hmmiles using "$obpath/Tab-PredProd-Drop_`zX'-$spec", $OR2_D3 append
reg hmiles L.hpmiles L.hmmiles $FullControls_PP, cluster(DrvID)
	outreg2 L.hpmiles L.hmmiles using "$obpath/Tab-PredProd-Drop_`zX'-$spec", $OR2_D3 append
areg hmiles L.hpmiles $TenureVars_PP, absorb(DrvID) cluster(DrvID)
	outreg2 L.hpmiles using "$obpath/Tab-PredProd-Drop_`zX'-$spec", $OR2_D3 append	
}	


/*==================================================================
4. DO BELIEFS PREDICT QUITTING? (Table 3)

kX = Regressor of interest
	~ foreach kX in hpmiles pmiles_d2 { 	
	hpmiles = predicted miles in hundreds of miles/wk, used for Table 3
	pmiles_d2 = dummy for above-median beliefs, used for Table E1
==================================================================*/

set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned_STQuits.dta", clear
foreach kX in hpmiles pmiles_d2 { 	
stcox `kX' if samp_base==1, nohr cluster(DrvID)
	outreg2 `kX' using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) replace
stcox hmmiles $MainControls, nohr cluster(DrvID)
	outreg2 hmmiles using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append
stcox hmmiles $MainControls if samp_base==1, nohr cluster(DrvID)
	outreg2 hmmiles using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append
stcox `kX' hmmiles if samp_base==1, nohr cluster(DrvID)
	outreg2 `kX' hmmiles using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append
stcox `kX' hmmiles $MainControls if samp_base==1, nohr cluster(DrvID)
	outreg2 `kX' hmmiles using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append	
}



/*==================================================================
5. RESPONSE TO THE BELIEF SURVEY
==================================================================*/

/*================================================
Appendix Table A1: Predicting Response to Belief Survey
================================================*/ 
set more off	
qui do "$fullpath/zz_globals_panel.do"	
use "$Tmp/Panel_Cleaned.dta", clear
drop if miles==0 | mi(miles)
drop if miles_p1==0 | mi(miles_p1)
reg respond $RespControls, cluster(DrvID)
	outreg2 $Demogs AgeYr schooling using "$obpath/Tab-BeliefRespond-$spec", $outreg2_nodec dec(3) replace
reg overconf2 $RespControls, cluster(DrvID)
	outreg2 $Demogs AgeYr schooling using "$obpath/Tab-BeliefRespond-$spec", $outreg2_nodec dec(3) append
reg respond hmpmiles_m1 $RespControls, cluster(DrvID)
	outreg2 $Demogs AgeYr schooling hmpmiles_m1 using "$obpath/Tab-BeliefRespond-$spec", $outreg2_nodec dec(3) append	
reg respond hoverconf2_mean_todate_m1 $RespControls if hoverconf2_mean_todate_m1>=-15 & hoverconf2_mean_todate_m1<=15, cluster(DrvID)
	outreg2 $Demogs AgeYr schooling hoverconf2_mean_todate_m1 using "$obpath/Tab-BeliefRespond-$spec", $outreg2_nodec dec(3) append
heckman overconf2 $RespControls if week>52, select(survey_share $RespControls) cluster(DrvID) 	
	outreg2 $Demogs AgeYr schooling survey_share using "$obpath/Tab-BeliefRespond-$spec", $outreg2_nodec addstat(rho,e(rho)) dec(3) append


/*================================================
Figure E1: Heterogeneity in Response Rates to Beliefs Survey
================================================*/
set more off
qui do "$fullpath/zz_globals_panel.do"		
use "$Tmp/Panel_Cleaned.dta", clear	
keep if fig_sample==1	
keep if ever_respond==1
collapse respond, by(DrvID)
histogram respond, start(0) width(0.05) ///
	xtitle(Average response rate) frequency ytitle(Frequency) graphr(fc(white))
graph export "$FigPath/Fig-PersonLevelRespRate-$spec.pdf", as(pdf) replace	



/*==================================================================
6. MORE ON PRODUCTIVITY BELIEFS
==================================================================*/


/*================================================
Figure E2: Tenure and Overconfidence (Beliefs - Productivity)

zX = Tenure restriction for making graph
	~ foreach zX in base restrict75 restrict100{
kX = Statistic of interest
	~ foreach kX in mean median {	

Panel (a): Means 
Panel (b): Medians 
Panel (c): Median, tenure>=75 and ever_resond==1	
================================================*/ 

set more off
foreach zX in base restrict75 restrict100{
foreach kX in mean median {	
use "$Tmp/Panel_Cleaned.dta", clear

* Added the below text to make the figure with miles_p1 instead of miles.
drop fig_sample
gen fig_sample = 1
replace fig_sample=0 if hadabp==1
replace fig_sample=0 if hadsalary==1
replace fig_sample=0 if pmiles==0 
replace fig_sample=0 if miles_p1==0

keep if fig_sample==1

gen V1 = "restrict75"
gen V2 = "restrict100"

assert ~mi(tenure) & ~mi(ever_respond)
drop if tenure<75 & V1=="`zX'"
drop if ever_respond==0 & V1=="`zX'"
drop if tenure<100 & V2=="`zX'"
drop if ever_respond==0 & V2=="`zX'"

collapse (`kX')overconf2, by(week)
twoway (lpolyci overconf2 week, bw(7) lwidth(thick)) (connected overconf2 week, msymbol(Oh)) ///
	if week>=6 & week<=110, xtitle(Week) ytitle(Miles per week) ///
	legend(lab(2 "Smoothed overconfidence") lab(3 "Overconfidence")) ///
	ylabel(-200(200)800) ymtick(-200(100)800) graphr(fc(white))
graph export "$FigPath/Fig-OverconfTenure-`kX'-`zX'-$spec.pdf", as(pdf) replace
}
}

/*================================================
Figure E3: Distribution of Overconfidence Across Drivers
================================================*/

* Panel A: Distribution of Individual Overconfidence
set more off
qui do "$fullpath/zz_globals_panel.do"	
use "$Tmp/Panel_Cleaned.dta", clear
foreach yX in miles pmiles {
	replace `yX'=. if `yX'==0
}
collapse miles pmiles, by(DrvID)
gen overconf2 = pmiles-miles
keep if overconf2<=1500
keep if overconf2>=-500
histogram overconf2, ///
	start(-500) width(50) xtitle(Overconfidence in Miles per Week) ///
	frequency ytitle(Frequency) graphr(fc(white))
graph export "$FigPath/Fig-OverconfByDrivHist-$spec.pdf", as(pdf) replace


* Panel B: Predicted Miles and Actual Miles
set more off
qui do "$fullpath/zz_globals_panel.do"	
use "$Tmp/Panel_Cleaned.dta", clear
foreach yX in miles pmiles {
	replace `yX'=. if `yX'==0
}
collapse miles pmiles, by(DrvID)
drop if miles>4000 | pmiles>4000
twoway (scatter miles pmiles) (line pmiles pmiles), ///
	xtitle(Predicted Miles) ytitle(Miles) ///
	legend(order(2 "45 Degree Line")) ///
	graphr(fc(white))
graph export "$FigPath/Fig-MilesPmilesScatter-$spec.pdf", as(pdf) replace

/*================================================
Table E4: Do Workers Update their Beliefs?
================================================*/
set more off	
qui do "$fullpath/zz_globals_panel.do"	
use "$Tmp/Panel_Cleaned.dta", clear
gen hmmiles_m1Xweek = hmmiles_m1 * week
label variable hmmiles_m1 "L. Avg miles to date"
label variable hmmiles_m1Xweek "Tenure X L. Avg miles to date"
label variable hmmiles_m2 "L2. Avg miles to date"
label variable hmiles_m1 "L. Miles"
areg hpmiles hmmiles_m1, absorb(week) cluster(DrvID)
	outreg2 hmmiles_m1 using "$obpath/Tab-BeliefUpdate-$spec", $outreg2_nodec dec(3) replace
areg hpmiles hmmiles_m1 $MainControls, absorb(week) cluster(DrvID)
	outreg2 hmmiles_m1 using "$obpath/Tab-BeliefUpdate-$spec", $outreg2_nodec dec(3) append
areg hpmiles hmmiles_m1 hmmiles_m1Xweek $MainControls, absorb(week) cluster(DrvID)
	outreg2 hmmiles_m1 hmmiles_m1Xweek using "$obpath/Tab-BeliefUpdate-$spec", $outreg2_nodec dec(3) append
areg hpmiles hmmiles_m2 hmiles_m1 $MainControls, absorb(week) cluster(DrvID)	
	outreg2 hmmiles_m2 hmiles_m1 using "$obpath/Tab-BeliefUpdate-$spec", $outreg2_nodec dec(3) append
areg hpmiles hmmiles_m1 i.week, absorb(DrvID) cluster(DrvID)
	outreg2 hmmiles_m1 using "$obpath/Tab-BeliefUpdate-$spec", $outreg2_nodec dec(3) append

			
/*================================================
Figure E4: Are Workers Overconfident About their Outside Option? 
Comapring Believed Outside Option vs. Outside Option
of Similar Workers in the CPS
================================================*/	

set more off	
use "$Tmp/Pooled_OppIncome.dta", clear
mean opp_income, over(group)
mean opp_income if incwage!=0, over(group)

* Believed Outside Option vs. Outside Option of CPS Workers
set more off	
qui do "$fullpath/zz_globals_panel.do"	
use "$Tmp/Pooled_OppIncome.dta", clear
drop if incwage==0 & (group==2 | group==3)
catplot group opp_income, ///
	percent(group) asyvars	///
	recast(bar) ///
	b1title("Annual income in thousands of dollars") ///
	ytitle(Percent share in bin) ylabel(0(5)30) ///
	graphr(fc(white))
graph export "$FigPath/Fig-OOvsCPS-$spec.pdf", as(pdf) replace		


* Beliefs about inside and outside option
set more off	
qui do "$fullpath/zz_globals_panel.do"	
use "$Tmp/Panel_Cleaned.dta", clear
reg ooearn pearn $FullControls_PP, cluster(DrvID)
	outreg2 pearn using "$obpath/Tab-OOEarnVsPEarn-$spec", $OR2_D3 replace

	
/*==================================================================
7. ROBUSTNESS ON BELIEFS AND QUITTING (TABLES E2-E3)
==================================================================*/	
		
/*================================================
Table E2: Do Beliefs Predict Quitting? Lagged Values Robustness
================================================*/			
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned_STQuits.dta", clear
* Require that non-missing lagged average productivity to date.
* Require that lagged productivity beliefs are in (0,5000].
gen samp_m1 = (~mi(hmmiles_m1) & pmiles_m1>0 & pmiles_m1<=5000)
label variable hpmiles_m1 "L. Predicted Miles"
label variable hmmiles_m1 "L. Avg miles to date"
foreach kX in hpmiles_m1 {
stcox `kX' if samp_m1==1, nohr cluster(DrvID)
	outreg2 `kX' using "$obpath/Tab-PredQuitsLag-`kX'-$spec", $outreg2_nodec dec(3) replace
stcox `kX' $MainControls if samp_m1==1, nohr cluster(DrvID)
	outreg2 `kX' using "$obpath/Tab-PredQuitsLag-`kX'-$spec", $outreg2_nodec dec(3) append
stcox hmmiles_m1 $MainControls, nohr cluster(DrvID)
	outreg2 hmmiles_m1 using "$obpath/Tab-PredQuitsLag-`kX'-$spec", $outreg2_nodec dec(3) append
stcox hmmiles_m1 $MainControls if samp_m1==1, nohr cluster(DrvID)
	outreg2 hmmiles_m1 using "$obpath/Tab-PredQuitsLag-`kX'-$spec", $outreg2_nodec dec(3) append
stcox `kX' hmmiles_m1 if samp_m1==1, nohr cluster(DrvID)
	outreg2 `kX' hmmiles_m1 using "$obpath/Tab-PredQuitsLag-`kX'-$spec", $outreg2_nodec dec(3) append
stcox `kX' hmmiles_m1 $MainControls if samp_m1==1, nohr cluster(DrvID)
	outreg2 `kX' hmmiles_m1 using "$obpath/Tab-PredQuitsLag-`kX'-$spec", $outreg2_nodec dec(3) append	
}	
	
		
/*================================================
Table E3: Do Beliefs Predict Quitting? 
Robustnesswith a Person's Average Belief to Date
================================================*/		
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned_STQuits.dta", clear		
gen samp_avg_lmiles = (~mi(miles) & ~mi(hmmiles_m1) & ~mi(pmiles) & ~mi(mpmiles) & mpmiles>0)
label variable hmpmiles "Avg predicted miles to date"
foreach kX in hmpmiles {
stcox `kX' if samp_avg_lmiles==1, nohr cluster(DrvID)
	outreg2 `kX' using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) replace
stcox `kX' $MainControls if samp_avg_lmiles==1, nohr cluster(DrvID)
	outreg2 `kX' using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append
stcox hmmiles_m1 $MainControls, nohr cluster(DrvID)
	outreg2 hmmiles_m1 using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append
stcox hmmiles_m1 $MainControls if samp_avg_lmiles==1, nohr cluster(DrvID)
	outreg2 hmmiles_m1 using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append
stcox `kX' hmmiles_m1 if samp_avg_lmiles==1, nohr cluster(DrvID)
	outreg2 `kX' hmmiles_m1 using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append
stcox `kX' hmmiles_m1 $MainControls if samp_avg_lmiles==1, nohr cluster(DrvID)
	outreg2 `kX' hmmiles_m1 using "$obpath/Tab-PredQuits-`kX'-$spec", $outreg2_nodec dec(3) append	
}	
		
	
/*==================================================================
8. MISC CLAIMS IN TEXT
==================================================================*/		

/*================================================
Median income in CPS is 32k
================================================*/
set more off
use "$Tmp/CPS2007_OppIncome.dta", clear
sum incwage if age==35, detail
assert r(p50)==32000


/*================================================
Share going to different occupations in exit survey.
================================================*/	
set more off
qui do "$fullpath/zz_globals_panel.do"
use "$Tmp/Panel_Cleaned.dta", clear	
by DrvID: egen max_firstwk = max(firstwk)	
assert max_firstwk==1
drop max_firstwk
keep if firstwk==1

		
* Drop Disabled, Retired, and Other from the calculation.
gen job_exit_new = job_exit
replace job_exit_new  = . if job_exit==6 | job_exit==7 | job_exit==8
label values job_exit_new wherenext
count if ~mi(job_exit_new)
scalar N_Exit = r(N)

* Nondriving job or Unemployed
count if job_exit_new==4 | job_exit_new==5
assert round(r(N)/N_Exit,.01)==.48

* Driving locally
count if job_exit_new==3
assert round(r(N)/N_Exit,.01)==.25

* OTR regional
count if job_exit_new==2
assert round(r(N)/N_Exit,.01)==.15

* OTR long haul
count if job_exit_new==1
assert round(r(N)/N_Exit,.01)==.12
		
		
