%{
====================================================
Function name: body_loglik_OC.m
Project: Overconfidence in trucking
Description: Body of the likelihood function.

Key parts for file:
- Create unobserved heterogeneity.
- Likelihood for data on miles.
- Solving the dynamic programming problem.
- Likelihood for data on attrition and beliefs.
- Overall likelihood.
====================================================
%}

% Set the globals.
set_globals;

% Set the options based on "op" vector.
options_op;

% Assign parameters based on options.
set_params; 


%% CREATE UNOBSERVED HETEROGENEITY.

% beliefbias: none, prior, prior_mp2, prior_normal, prior_mp2_corr,
%       prior_normal_corr
tnodes = 0;
twts = 1;
bnodes = 0;
bwts = 1;

% Taste UH is normally distributed or has Heckman-Singer 
% mass points. "TNODES" is the number of mass points. 
if strcmp(substr(tasteuh,0,6),'normal')==1 
    [tnodes,twts]=qnwnorm(TNODES,mu_alp,sig_alp^2);
elseif strcmp(substr(tasteuh,0,3),'mp2')==1
    twts = [puh12;1-puh12];
    tnodes = [mu1;mu2];
    TNODES=2;
elseif strcmp(substr(tasteuh,0,3),'mp3')==1
    twts = [puh13;puh23;1-puh13-puh23];
    tnodes = [mu1;mu2;mu3];
    TNODES=3;
elseif strcmp(substr(tasteuh,0,3),'mp4')==1
    twts = [puh14;puh24;puh34;1-puh14-puh24-puh34];
    tnodes = [mu1;mu2;mu3;mu4];
    TNODES=4;
elseif strcmp(substr(tasteuh,0,3),'mp5')==1
    twts = [puh15;puh25;puh35;puh45;1-puh15-puh25-puh35-puh45];
    tnodes = [mu1;mu2;mu3;mu4;mu5];
    TNODES=5;
elseif strcmp(substr(tasteuh,0,3),'mp6')==1
    twts = [puh16;puh26;puh36;puh46;puh56;1-puh16-puh26-puh36-puh46-puh56];
    tnodes = [mu1;mu2;mu3;mu4;mu5;mu6];
    TNODES=6;
elseif strcmp(tasteuh,'no')==1
    TNODES=1;
end

% Unobserved heterogeneity in people's beliefs
% beliefbias: no_use_beliefs, no_bias, prior, prior_mp, 
    % prior_normal, prior_mp2_corr, prior_normal_corr
if strcmp(beliefbias,'prior')==1
    bnodes = eta_b;
elseif strcmp(beliefbias,'prior_normal')==1
    [bnodes,bwts]=qnwnorm(BNODES,eta_0b,sig_0b^2); % Gauss-Hermite quadrature
elseif strcmp(beliefbias,'prior_mp2')==1 || strcmp(beliefbias,'prior_mp2_2types')==1
    bwts = [puhb12;1-puhb12];
    bnodes = [eta_1b;eta_2b];
elseif strcmp(beliefbias,'prior_mp3')==1 || strcmp(beliefbias,'prior_mp3_3types')==1
    bwts = [puhb13;puhb23;1-puhb13-puhb23];
    bnodes = [eta_1b;eta_2b;eta_3b];
elseif strcmp(beliefbias,'prior_mp4')==1 || strcmp(beliefbias,'prior_mp4_4types')==1
    bwts = [puhb14;puhb24;puhb34;1-puhb14-puhb24-puhb34];
    bnodes = [eta_1b;eta_2b;eta_3b;eta_4b];
elseif strcmp(beliefbias,'prior_mp5')==1 || strcmp(beliefbias,'prior_mp5_5types')==1
    bwts = [puhb15;puhb25;puhb35;puhb45;1-puhb15-puhb25-puhb35-puhb45];
    bnodes = [eta_1b;eta_2b;eta_3b;eta_4b;eta_5b];
elseif strcmp(beliefbias,'prior_mp6')==1 || strcmp(beliefbias,'prior_mp6_6types')==1
    bwts = [puhb16;puhb26;puhb36;puhb46;puhb56;1-puhb16-puhb26-puhb36-puhb46-puhb56];
    bnodes = [eta_1b;eta_2b;eta_3b;eta_4b;eta_5b;eta_6b];
end
if strcmp(tasteuh,'mp2_nomu2_corr')==1 && strcmp(beliefbias,'prior_mp2_corr')==1
    twtsbwts = [p11 p12; 1-p11-p12-p22 p22];
    tnodes = [mu1;mu2];
    TNODES=2;
    bnodes = [eta_1b;eta_2b];
end

%% LIKELIHOOD FOR DATA ON MILES

% Before specifiying likelihood, define TIME TRENDS.
% "atrend" is the same a(t) in the model.
% "amtrend" can be used for de-trending average miles to date:
% De-trended average miles to date = average miles to date - amtrend.
% Our code assumes NPER>=NDEC. Earlier versions of the code allowed
% for NPER<NDEC.
atrend = zeros(NPER,1); amtrend = zeros(NPER,1);

if strcmp(timetrend,'logit')==1
atrend(T_NOLEARN+1:NPER) = 2*a1*(-.5+LogitMH(a2*(0:1:NPER-1-T_NOLEARN)'));
for t=T_NOLEARN+1:NPER
    amtrend(t) = mean(atrend(T_NOLEARN+1:t));
end
end

if strcmp(timetrend,'logit_firststage')==1
a1 = a1new;
a2 = a2new;
atrend(T_NOLEARN+1:NPER) = 2*a1*(-.5+LogitMH(a2*(0:1:NPER-1-T_NOLEARN)'));
for t=T_NOLEARN+1:NPER
    amtrend(t) = mean(atrend(T_NOLEARN+1:t));
end
end


% gamma is vector of learning weights under optimal learning (see App. D).
% Omega is actual variance of y_t given y1, ..., yt-1.
gamma = zeros(NPER,1); Omega = zeros(NPER,1);
for t=1+T_NOLEARN:NPER
    gamma(t)=((t-T_NOLEARN)*(sig_0^2)/((t-T_NOLEARN)*(sig_0^2)+(sig_y^2)));
    Omega(t)=(((sig_0^2)*(sig_y^2))/((t-T_NOLEARN)*(sig_0^2)+sig_y^2)) + sig_y^2;
end
omega = sqrt(Omega); 

% gamma_b is vector of learning weights assuming biased learning.
% Omega_b is believed variance for y_t given y1, ..., yt-1.
gamma_b = zeros(NPER,1); Omega_b = zeros(NPER,1);
for t=1+T_NOLEARN:NPER
    gamma_b(t)=((t-T_NOLEARN)*(sig_0^2)/((t-T_NOLEARN)*(sig_0^2)+(sig_y_tilda^2)));
    Omega_b(t)=(((sig_0^2)*(sig_y_tilda^2))/((t-T_NOLEARN)*(sig_0^2)+sig_y_tilda^2)) + sig_y_tilda^2;
end
omega_b = sqrt(Omega_b);


% Believed transition matrix for mean miles to mean miles is 
% "mearn2mearn". It depends on period and belief bias. 
% Formula in Appendix D.
mearn2mearn=zeros(NGRID,NGRID,NPER,BNODES);
for m=1:BNODES
    for t=1:NPER
        mearn2mearn(:,:,t,m) = eye(NGRID);
    end
end

% "block_i" and "block_j" are NGRID x 1.
% "block_1" (block one) is used for perceived chance of transitioning
% to lowest grid point in next period. It is NGRID x 1.
% The same part of "block_i" is used for "block_big" and "block_small".
% "block_big" and "block_small" are each NGRID x (NGRID-1).
% Note that denom has "omega_b", which is sqrt of "Omega_b".
for m=1:BNODES
    for t=1+T_NOLEARN:NPER
        tt=t-T_NOLEARN;
        block_i = -(tt-1)*grid_ys - atrend(t)-pred_y(gamma_b(t-1),eta0+bnodes(m),grid_ys-amtrend(t-1));
        block_j = tt*thres_ys;
        block_1 = block_i + ones(NGRID,1)*block_j(1)';
        mearn2mearn(:,1,t,m) = normcdf(block_1 / omega_b(t));
        block_big = block_i*ones(1,NGRID-1) + ones(NGRID,1)*block_j(2:NGRID)';
        block_small = block_i*ones(1,NGRID-1) + ones(NGRID,1)*block_j(1:NGRID-1)';
        mearn2mearn(:,2:NGRID,t,m) = normcdf((block_big)/omega_b(t))-normcdf((block_small)/omega_b(t));
    end
end

% DE-TRENDED RAW MILES OR AVERAGE MILES. RAW MEANS NOT DISCRETIZED.
% Subtract trend except if missing.
dt_earn_raw = earn_raw; dt_mearn_raw = mearn_raw;
for t=T_NOLEARN+1:NDEC 
dt_earn_raw(:,t)=(earn_raw(:,t)-atrend(t)).*(1*(earn_raw(:,t)~=-9))-9*(earn_raw(:,t)==-9);
dt_mearn_raw(:,t)=(mearn_raw(:,t)-amtrend(t)).*(1*(mearn_raw(:,t)~=-9))-9*(mearn_raw(:,t)==-9);
end

% DE-TRENDED MILES ON THE GRID.
dt_earn = -9*(dt_earn_raw==-9); dt_mearn = -9*(dt_mearn_raw==-9);
% Assign to grid point one if positive miles and below threshold one.
for tX=1+T_NOLEARN:NDEC
dt_earn(:,tX)= dt_earn(:,tX) + grid_ys(1)*(dt_earn_raw(:,tX)>0 & dt_earn_raw(:,tX)<=thres_ys(1)).*ones(NOBS,1);
dt_mearn(:,tX)= dt_mearn(:,tX) + grid_ys(1)*(dt_mearn_raw(:,tX)>0 & dt_mearn_raw(:,tX)<=thres_ys(1)).*ones(NOBS,1);
end
% Assign to grid point k if above thres (k-1) and below thres (k).
for tX=1+T_NOLEARN:NDEC
for k=2:NGRID
dt_earn(:,tX)= dt_earn(:,tX) + grid_ys(k)*(dt_earn_raw(:,tX)>thres_ys(k-1) & dt_earn_raw(:,tX)<=thres_ys(k)).*ones(NOBS,1);
dt_mearn(:,tX)=dt_mearn(:,tX)+ grid_ys(k)*(dt_mearn_raw(:,tX)>thres_ys(k-1) & dt_mearn_raw(:,tX)<=thres_ys(k)).*ones(NOBS,1);
end
end

% Dummies for a person's de-meaned mean earnings at a given time
dd_dt_mearn = zeros(NOBS,NGRID,NPER);
for t=1:NDEC
    for j=1:NGRID
        dd_dt_mearn(:,j,t)= (dt_mearn(:,t)==grid_ys(j))*1;
    end
end
for t=1:T_NOLEARN
    dd_dt_mearn(:,round(length(grid_ys)/2),t)=ones(NOBS,1);
end

% "z2" is the driverXweek part of the likelihood.
z2 = zeros(NOBS,NDEC);
keep_ll2 = zeros(NOBS,NDEC);

% "p2" is part of likelihood associated with miles. "p2" is Nx1.
% Define it first for the first week of learning after training.
p2 = normpdf(earn_raw(:,T_NOLEARN+1),eta0+atrend(T_NOLEARN+1),sqrt(sig_0^2 + sig_y^2)).*(earn_raw(:,T_NOLEARN+1)>0)...
    +1*(earn_raw(:,T_NOLEARN+1)<=0);


% Build up "p2" with additional weeks beyond T_NOLEARN+1.
% Restrict attention to weeks with positive raw miles.
% Note that "omegta(tX-1)" is in denominator, equal to sqrt(Omega).
for tX=T_NOLEARN+2:NDEC
    z2(:,tX)=normpdf(earn_raw(:,tX),(1-gamma(tX-1))*eta0+ gamma(tX-1)*dt_mearn_raw(:,tX-1)+ atrend(tX),omega(tX-1));
    keep_ll2(:,tX) = (earn_raw(:,tX)>0).*(dt_mearn_raw(:,tX-1)~=-9)*1;
    p2 = p2.*(z2(:,tX).*keep_ll2(:,tX)+ 1*(1-keep_ll2(:,tX)));
end

%% SOLVE THE DYNAMIC PROGRAMMING PROBLEM.

% "oowage" is the outside option wage. In the baseline, it involves
% skill accumulation during first several weeks. But can instead 
% involve gradual skill accumulation.
oowage = ones(NPER,1)*rwage(1);
for t=1:T_NOLEARN
    oowage(t) = oowage(t)- ((T_NOLEARN+1-t)/T_NOLEARN)*v_ojt;
end
if strcmp(ootimetrend,'logit')==1
    oowage = oowage + 2*theta1*(-.5+LogitMH(theta2*(0:1:NPER-1)'));
end

% VQ_bar is vector of choice-specific values for quitting the firm.
VQ_bar = zeros(NPER+1,1);
% VQ_bar(1:NPER) are the time-indexed choice-specific value functions.
VQ_bar(1:NPER) = oowage/(1-delta);
% VQ_bar(NPER+1) is asymptotic value function. Outside option is 
% same as in period NPER.
VQ_bar(NPER+1) = oowage(NPER)/(1-delta);
% We also use "VQ_barinf" to denote asymptotic value function.
VQ_barinf = VQ_bar(NPER+1);

% Share of the quit penalty experienced in utility. For robustness, 
% one can experiment with a share below 1.
s_penalty_felt = 1;

% As stated in Appendix D, the penalty used is $3,750.
penalty_12m = 37.5;

% Pain of quit penalty experienced immediately in utility terms.
if strcmp(contract,'12month')==1 
    VQ_bar(1:52)=VQ_bar(1:52)-s_penalty_felt*penalty_12m;
end

% VS_bar is choice-specific value functions associated with
% staying at the job. 
VS_bar_full = zeros(NPER+1,NGRID,TNODES*BNODES,COVARSTATES);

for rx = 1:COVARSTATES

if strcmp(covariates,'ref1')==1 && rx==2
    tnodes=tnodes + alpha_ref1;
end
    
% The Rust (87) inner loop tolerance, "tol_InnerLoop", is set 
% in "read_data.m".    
VS_barinf = ones(NGRID,TNODES*BNODES);
diff_S = 1;
tnodesnew = [];
% "tnodesnew" will be 1xTNODES matrix.
for m=1:TNODES
    tnodesnew = [tnodesnew repmat(tnodes(m),1,BNODES)];
end

while (diff_S>tol_InnerLoop)
    VS_barinf_new = (milepay(NPER)*(grid_ys-amtrend(NPER)+atrend(NPER)))*ones(1,TNODES*BNODES)...
    + ones(NGRID,1)*tnodesnew + delta*tau*log(exp(VS_barinf/tau)+exp(VQ_barinf/tau));   
    diff_S = max(max(abs(VS_barinf_new-VS_barinf)));
    VS_barinf = VS_barinf_new;
end

% EV(:,:,t) is the expected value or EMax of the choice-specific value 
% functions during period t: EV(:,:,t) = Emax(VS(t),VQ(t)).
% The final period, NPER+1, is the period for the asymptotic value funcs.
EV=zeros(NGRID,TNODES*BNODES,NPER+1);
VS_bar = zeros(NGRID,TNODES*BNODES,NPER+1);
VS_bar(:,:,NPER+1)=VS_barinf;
EV(:,:,NPER+1)= tau*log(exp(VS_barinf/tau)+exp(VQ_barinf/tau));

% Use backward induction to solve for value functions from 1 to T.
% "n_m" is the counter for the taste UH nodes.
% "bn_m" is the counter for the belief nodes.

% Start in period T (NPER). Then go backward until period T_NOLEARN+1.
% Last period done is tt=NPER+1-t=NPER+1-(NPER-T_NOLEARN)=T_NOLEARN+1.
% The reason why all the time subscripts are "tt" here is because
% we are using "tt" to backward in time (instead of substracting
% 5 weeks for on-the-job training).
for m=1:TNODES*BNODES
    n_m = ceil(m/BNODES); 
    bn_m = mod(m,BNODES)*(mod(m,BNODES)~=0)+BNODES*(mod(m,BNODES)==0); 
    for t=1:NPER-T_NOLEARN
        tt=NPER+1-t;
        VS_bar(:,m,tt)= milepay(tt)*(atrend(tt)+pred_y(gamma_b(tt-1),eta0+bnodes(bn_m),grid_ys-amtrend(tt-1)))...
            +tnodes(n_m)+delta*mearn2mearn(:,:,tt,bn_m)*EV(:,m,tt+1);
        EV(:,m,tt)=tau*log(exp(VS_bar(:,m,tt)/tau)+exp(VQ_bar(tt)/tau));
    end
end

% Driver pay during training. See FN in Section 4.1.
TRAINING_PAY = 3.75;  

% Value functions during on-the-job training. As noted in FN in paper, 
% non-pecuniary taste for the job is zero during on-the-job training. 
% Estimates are very similar if this is relaxed. 
for m=1:TNODES*BNODES
    n_m = ceil(m/BNODES); 
    bn_m = mod(m,BNODES)*(mod(m,BNODES)~=0)+BNODES*(mod(m,BNODES)==0); 
    for t=1:T_NOLEARN
        tt=T_NOLEARN+1-t;
        VS_bar(:,m,tt)=TRAINING_PAY+delta*mearn2mearn(:,:,tt,bn_m)*EV(:,m,tt+1);
        EV(:,m,tt)=tau*log(exp(VS_bar(:,m,tt)/tau)+exp(VQ_bar(tt)/tau));
    end
end

% Convert VS_bar=(NGRID,TNODES*BNODES,NPER+1) to (NPER+1,NGRID,TNODES*BNODES)
VS_bar =  permute(VS_bar, [3 1 2]);
VS_bar_full(:,:,:,rx) = VS_bar; 

end % This ends the statement: for rx=1:COVARSTATES

VS_bar = VS_bar_full;

% "pr_s" is the predicted probability of staying.
pr_s = zeros(NPER,NGRID,TNODES*BNODES,COVARSTATES);
for rx=1:COVARSTATES
for m=1:TNODES*BNODES
    for bb=1:NGRID
        pr_s(:,bb,m,rx) = LogitMH((VS_bar((1:NPER),bb,m,rx)-VQ_bar(1:NPER))/tau);
    end
end
end


%% LIKELIHOOD FOR DATA ON ATTRITION AND BELIEFS. 
% The attrition part is computed using solution to DP.

% "pp3" is part of likelihood from the beliefs data.
pp3= ones(NOBS,length(bnodes));

% "pp" is part of likelihood from attrition data.
% "z" is the raw likelihood for a given week and set of UH nodes.
% "keep_ll" indicates whether the "z" of a given person will count
% toward the likelihood for a particular week and set of nodes.
pp= ones(NOBS,TNODES*BNODES);
z = zeros(NOBS,NDEC,TNODES*BNODES);
keep_ll = zeros(NOBS,NDEC,TNODES*BNODES);

% "p_p3" is part of likelihood from beliefs and attrition, that is,
% everything besides miles/earnings. Earnings still enter p_p3, but 
% only as variables to condition on. 
% NOTE THAT WE USE "ZEROS" INSTEAD OF "ONES" TO PRE-ASSIGN BECAUSE
% "P_P3" IS BASED ON A SUM OVER UH TYPES. IN CONTRAST, "PP" AND 
% "PP3" ARE BASED ON PRODUCTS.
p_p3=zeros(NOBS,1);

%{
Workers are asked in t to predict miles in t+1.
PERIOD AFTER TRAINING: No signals, so prediction based on eta0 + bnodes(m).
MIDDLE PERIODS: bt ~ N(Eb(y_t+1),sig_b). 
LAST PERIOD: bt ~ N(Eb(y_t+1),sig_b). Use a(T) for a(T+1).
Use "sqrt(sig_b^2)" instead "sig_b" to prevent "sig_b" from going negative.
%}

% Include only positive beliefs in the likelihood.
if strcmp(beliefbias,'no_use_beliefs')==0
for m=1:length(bnodes)
pp3(:,m) = normpdf(beliefs_raw(:,T_NOLEARN+1),eta0+bnodes(m)+atrend(T_NOLEARN+2),sqrt(sig_b^2)).*(beliefs_raw(:,T_NOLEARN+1)>0)...
    +1*(beliefs_raw(:,T_NOLEARN+1)<=0);
for t=T_NOLEARN+2:NDEC
    z3(:,m,t)=normpdf(beliefs_raw(:,t),(1-gamma_b(t-1))*(eta0+bnodes(m))+gamma_b(t-1)*dt_mearn_raw(:,t-1)+ atrend(t+1),sqrt(sig_b^2));
    keep_ll3(:,t) = (beliefs_raw(:,t)>0).*(dt_mearn_raw(:,t-1)~=-9)*1;
    pp3(:,m) = pp3(:,m).*(z3(:,m,t).*keep_ll3(:,t)+ 1*(1-keep_ll3(:,t)));
end
end
end


if strcmp(tasteuh,'mp2_2types')
    twtsbwts = [twts(1);0;0;twts(2)];
end
if strcmp(tasteuh,'mp3_3types')
    twtsbwts = [twts(1);0;0;0;twts(2);0;0;0;twts(3)];
end
if strcmp(tasteuh,'mp4_4types')
    twtsbwts = [twts(1);0;0;0;0;twts(2);0;0;0;0;twts(3);0;0;0;0;twts(4)];
end
if strcmp(tasteuh,'mp5_5types')
    twtsbwts = [twts(1);zeros(4,1)];
    twtsbwts = [twtsbwts;0;twts(2);zeros(3,1)];
    twtsbwts = [twtsbwts;zeros(2,1);twts(3);zeros(2,1)];
    twtsbwts = [twtsbwts;zeros(3,1);twts(4);0];
    twtsbwts = [twtsbwts;zeros(4,1);twts(5)];
end
if strcmp(tasteuh,'mp6_6types')
    twtsbwts = [twts(1);zeros(5,1)];
    twtsbwts = [twtsbwts;0;twts(2);zeros(4,1)];
    twtsbwts = [twtsbwts;zeros(2,1);twts(3);zeros(3,1)];
    twtsbwts = [twtsbwts;zeros(3,1);twts(4);zeros(2,1)];
    twtsbwts = [twtsbwts;zeros(4,1);twts(5);0];
    twtsbwts = [twtsbwts;zeros(5,1);twts(6)];
end


%pr_s = NPER,NGRID,TNODES*BNODES,COVARSTATES change to 
%       NGRID,COVARSTATES,NPER,TNODES*BNODES
pr_s = permute(pr_s, [2 4 1 3]);

% "n_m" is counter for taste nodes. "bn_m" is counter for belief nodes.
for m=1:TNODES*BNODES
n_m = ceil(m/BNODES); 
bn_m = mod(m,BNODES)*(mod(m,BNODES)~=0)+BNODES*(mod(m,BNODES)==0); 
for tX=1:NDEC
z(:,tX,m) = sum(dd_covars.*(dd_mearn(:,:,tX)*pr_s(:,:,tX,m)),2).*(stay(:,tX)==1)...
    + sum(dd_covars.*(dd_mearn(:,:,tX)*(1-pr_s(:,:,tX,m))),2).*(stay(:,tX)==0);
keep_ll(:,tX,m)=(sum(dd_mearn(:,:,tX),2)==1).*(stay(:,tX)~=-9);
pp(:,m)=pp(:,m).*(z(:,tX,m).*keep_ll(:,tX,m)+ 1*(1-keep_ll(:,tX,m)));
end

% The first "if" here applies to our main case: tasteuh = 'mp3'.
if strcmp(tasteuh,'mp2_nomu2_corr')~=1 ...
    && strcmp(tasteuh,'mp2_2types')~=1 && strcmp(tasteuh,'mp3_3types')~=1 ...
    && strcmp(tasteuh,'mp4_4types')~=1 && strcmp(tasteuh,'mp5_5types')~=1 ...
    && strcmp(tasteuh,'mp6_6types')~=1
p_p3 = p_p3 + twts(n_m)*bwts(bn_m)*pp(:,m).*pp3(:,bn_m);
elseif strcmp(tasteuh,'mp2_nomu2_corr')==1
p_p3 = p_p3 + twtsbwts(n_m,bn_m)*pp(:,m).*pp3(:,bn_m);
elseif strcmp(tasteuh,'mp2_2types')==1 || strcmp(tasteuh,'mp3_3types')==1 ...
    || strcmp(tasteuh,'mp4_4types')==1 || strcmp(tasteuh,'mp5_5types')==1 ...
    || strcmp(tasteuh,'mp6_6types')==1
p_p3 = p_p3 + twtsbwts(m)*pp(:,m).*pp3(:,bn_m);
end

end


%% OVERALL LIKELIHOOD
 
%As a precaution.
if exist('p_p3')
    p_p3=p_p3.*(p_p3>1e-150) + 1e-150*(p_p3<=1e-150);  
end

% When estimating only the miles/earnings parameters, ignore the portion
% of the likelihood from attrition and beliefs (i.e., set to one).
if strcmp(baseline,'earn_params_only')==1
    p_p3 = ones(NOBS,1);
end

%{
"ll" is the final log-likelihood. As noted in Appendix D, it is comprised
of two components. The first one, "p_p3", is the component corresponding
to the likelihood from attrition data and subjective belief data.
The second one, "p2", is the component from miles/earnings.
%}

%{
Before adding the correction for possible inv prob weighting, we had:
ll=-sum(log(p_p3),1)-sum(log(p2),1);  
%}
%Negative since neg of ll is minimized
ll=-sum((1./pred_respond).*log(p_p3),1)-sum((1./pred_respond).*log(p2),1);  
% Normalizing constant for ipw
ll = ll*sum(pred_respond)/NOBS; 

% Require that learning by doing is positive.
if a1<0 || a2<0
    ll=99999999;
end

% Require that logit skill accumulation is positive.
if strcmp(ootimetrend,'logit')==1 && (theta1<0 || theta2<0)
    ll=99999999;
end


% When 3 types of taste UH, impose each prob in (0,1).
if strcmp(tasteuhprobrestrict,'no')==1 
if (puh13+puh23>1) || puh13<0 || puh23<0
    ll=99999999;
end
end

% Impose that taste for job cannot be excessively negative.
if strcmp(tasteuh,'mp3')==1 && strcmp(timetrend,'no')==1 
    if mu1<op.MU_LB_BASE || mu2<op.MU_LB_BASE || mu3<op.MU_LB_BASE
        ll=99999999;
    end
end
if strcmp(tasteuh,'mp3')==1 && strcmp(timetrend,'logit')==1
    if mu1<op.MU_LB_LBD || mu2<op.MU_LB_LBD || mu3<op.MU_LB_LBD
        ll=99999999;
    end
end



