%{
====================================================
Script name: predict_sims_OC.m
Project: Overconfidence in trucking
Description: Simulates the model and performs
debiasing counterfactual.

PARTS OF THE CODE:
1. Set the options and parameters for simulations.
2. Simulate the data.
~ Make the graphs.
~ Calculate profits and welfare.
====================================================
%}
%profile on
tic;

%% 1. SET THE OPTIONS AND PARAMETERS FOR SIMULATIONS.

% Which counterfactual would we like to analyze?
% As specified in "zz_std_options.m", standard is 'none'.
% Set in Master.m if want to do 'elim_overconf'.


% NPER_SIM: Number of periods for simulating forward
%{
Recall that "NPER" is number of periods before learning 
believed complete. Model can be simulated beyond this.

~ NPER_SIM=NPER;  % Used for making the 4-frame picture of model fit.
~ NPER_SIM = 1300; % Used for calculating profits under debiasing.
%}
if strcmp(counterfactual,'none')==1
    NPER_SIM=NPER;
elseif strcmp(counterfactual,'elim_overconf')==1
    NPER_SIM = 1300; 
end
        
% SIM_PERS: Number of simulated persons
if strcmp(counterfactual,'none')==1
    SIM_PERS = 200000;
elseif strcmp(counterfactual,'elim_overconf')==1   
    SIM_PERS = 20000; 
end

% # of periods for interim profit calculation
NPER_PROFIT_CALC=110;  

% Set discount factors for firm equal to that of worker. 
delta_firm = delta;

% Set the training contract assumed. 
contract = op.contract;

% Drivers are assumed to pay 30% of the quit penalties with no delay.
COLLECTRATE = .3;

%{
In counteractuals, "overconf_factor" is the number we multiply by the
estimated overconfidence parameter. For example, setting overconf_factor
equal to 0.5 means we debias half a worker's overconfidence. IT IS
BEST NOT TO SET IT EXACTLY EQUAL TO 0. Instead, we set it to the small
number, zero_overconf.
Alternatives: 1, 0.5, zero_overconf.
%}
zero_overconf = 1e-7;  

% Training contract. This paper only does 12-month contract.
% Different training contracts analyzed in another paper.
penalty_12m = 37.5;
kvector = zeros(NPER,1);
if strcmp(contract,'12month')==1
    kvector(1:NDEC_DATA) = [penalty_12m*ones(52,1) ; zeros(58,1)];
end

% Wage per mile information
milepay = ones(NPER,1);
% Separate script setting pay per mile. THIS IS CONFIDENTIAL INFO.
set_mile_pay; 

%{
In optimal contract analysis, "wagefac" is the factor we multiply by 
the rate per mile to get the wages that were used in practice. This
should be 1 for cases when we are not doing optimal contract analysis.
%}
wagefac = 1;

% Multiply wage per mile by a multiplicative factor.
milepay = wagefac*milepay;

% Parameters for the profits analysis.
%{
From set-up for Counterfactuals Section.
%}
P_minus_MC = 0.7;
margin = P_minus_MC-milepay; % Profit margin
margin(1:T_NOLEARN)=0;
FIXEDCOST = 6.50; % Fixed cost.
TRAINCOST = 25; % Cost of training a new driver.
TRAINING_PAY = 3.75; % Driver pay during training. 

ZProfitParams = [P_minus_MC;100*FIXEDCOST;100*TRAINCOST;...
    NPER_PROFIT_CALC;NPER_SIM;delta_firm^52];

% Weeks where calculate retention in counterfactuals.
% If we look at "surviv(tt1)", this is survival to start of week tt1.
tt1 = 20;
tt2 = 40;
tt3 = 60;

% CFDRAWS refers to the number of draws in the counterfactual simulations.
CFDRAWS=1;
if strcmp(counterfactual,'elim_overconf')==1
    CFDRAWS=2;
end

%% 2. SIMULATE THE DATA.

% Matrix for storing the simulated stay/leave decisions.
sim_stay = zeros(SIM_PERS,NPER_SIM,CFDRAWS); 

for cfdraw = 1:CFDRAWS

% Set "coef" using parameter estimates, "paramhat".
coef=paramhat;    
eta_1b=0; 
eta_2b=0;
eta_3b=0;

% Set the parameters. Take what's in "coef" and insert Matlab
% objects named after the diff variables like "tau" and "eta0".
set_params;     
    
if cfdraw==2
    eta_b=overconf_factor*eta_b;
    eta_1b = overconf_factor*eta_1b;
    eta_2b = overconf_factor*eta_2b;
    eta_3b = overconf_factor*eta_3b;
end

% Time trend
% "atrend" is the same a(t) in the model.
% "amtrend" can be used for de-trending average miles to date:
% De-trended average miles to date = average miles to date - amtrend.
atrend = zeros(NPER,1); amtrend=zeros(NPER,1);

if strcmp(timetrend,'logit')==1
atrend(T_NOLEARN+1:NPER) = 2*a1*(-.5+LogitMH(a2*(0:1:NPER-1-T_NOLEARN)'));
for t=T_NOLEARN+1:NPER
    amtrend(t) = mean(atrend(T_NOLEARN+1:t));
end
end

if strcmp(timetrend,'logit_firststage')
a1 = a1new;
a2 = a2new;
atrend(T_NOLEARN+1:NPER) = 2*a1*(-.5+LogitMH(a2*(0:1:NPER-1-T_NOLEARN)'));
for t=T_NOLEARN+1:NPER
    amtrend(t) = mean(atrend(T_NOLEARN+1:t));
end
end

% If simulating beyond NPER, we assume that the trend stops growing
% at t=NPER.
if exist('NPER_SIM') && NPER_SIM>NPER
    atrend = [atrend ; atrend(NPER)*ones(NPER_SIM-NPER,1)];
    amtrend = [amtrend ; amtrend(NPER)*ones(NPER_SIM-NPER,1)];
end

% gamma is the vector of learning weights. 
gamma = zeros(NPER,1); Omega = zeros(NPER,1);
for t=1+T_NOLEARN:NPER
    gamma(t)=((t-T_NOLEARN)*(sig_0^2)/((t-T_NOLEARN)*(sig_0^2)+(sig_y^2)));
    Omega(t)=(((sig_0^2)*(sig_y^2))/((t-T_NOLEARN)*(sig_0^2)+sig_y^2)) + sig_y^2;
end
omega = sqrt(Omega); 

gamma_b = zeros(NPER,1); Omega_b = zeros(NPER,1);
for t=1+T_NOLEARN:NPER
    gamma_b(t)=((t-T_NOLEARN)*(sig_0^2)/((t-T_NOLEARN)*(sig_0^2)+(sig_y_tilda^2)));
    Omega_b(t)=(((sig_0^2)*(sig_y_tilda^2))/((t-T_NOLEARN)*(sig_0^2)+sig_y_tilda^2)) + sig_y_tilda^2;
end
omega_b = sqrt(Omega_b);


% Simulate covariates: no longer done, so removed.
% "dd_sim_covars" is matrix of dummies for covariates.
% If covariates=='no_covars', it's just a column of ones.
dd_sim_covars = ones(SIM_PERS,1);

% Euler's constant.
euler = -psi(1);

% Simulate the idiosyncratic shocks. EV(1) distribution.
SEED1=1234;  
rand('state',SEED1);
sim_e1 = -tau*log(-1*log(rand(SIM_PERS,NPER)))-tau*euler;
sim_e2 = -tau*log(-1*log(rand(SIM_PERS,NPER)))-tau*euler;
if exist('NPER_SIM') && NPER_SIM>NPER
    sim_e1 = -tau*log(-1*log(rand(SIM_PERS,NPER_SIM)))-tau*euler;
    sim_e2 = -tau*log(-1*log(rand(SIM_PERS,NPER_SIM)))-tau*euler;
end

% Simulate the unobserved heterogeneity in mass-points.
SEED2=4321; 
rand('state',SEED2);
tastempdraw = rand(SIM_PERS,1);
beliefmpdraw = rand(SIM_PERS,1);


tnodes = 0;
twts = 1;
bnodes = 0;
bwts = 1;

% Taste UH is normally distributed or has Heckman-Singer 
% mass points. "TNODES" is the number of mass points. 
if strcmp(substr(tasteuh,0,6),'normal')==1 
    [tnodes,twts]=qnwnorm(TNODES,mu_alp,sig_alp^2);
elseif strcmp(substr(tasteuh,0,3),'mp2')==1
    twts = [puh12;1-puh12];
    tnodes = [mu1;mu2];
    TNODES=2;
elseif strcmp(substr(tasteuh,0,3),'mp3')==1
    twts = [puh13;puh23;1-puh13-puh23];
    tnodes = [mu1;mu2;mu3];
    TNODES=3;
elseif strcmp(substr(tasteuh,0,3),'mp4')==1
    twts = [puh14;puh24;puh34;1-puh14-puh24-puh34];
    tnodes = [mu1;mu2;mu3;mu4];
    TNODES=4;
elseif strcmp(substr(tasteuh,0,3),'mp5')==1
    twts = [puh15;puh25;puh35;puh45;1-puh15-puh25-puh35-puh45];
    tnodes = [mu1;mu2;mu3;mu4;mu5];
    TNODES=5;
elseif strcmp(substr(tasteuh,0,3),'mp6')==1
    twts = [puh16;puh26;puh36;puh46;puh56;1-puh16-puh26-puh36-puh46-puh56];
    tnodes = [mu1;mu2;mu3;mu4;mu5;mu6];
    TNODES=6;
elseif strcmp(tasteuh,'no')==1
    TNODES=1;
end

% Unobserved heterogeneity in people's beliefs
% beliefbias: no_use_beliefs, no_bias, prior, prior_mp, 
    % prior_normal, prior_mp2_corr, prior_normal_corr

if strcmp(beliefbias,'prior')==1
    bnodes = eta_b;
elseif strcmp(beliefbias,'prior_normal')==1
    [bnodes,bwts]=qnwnorm(BNODES,eta_0b,sig_0b^2); % Gauss-Hermite quadrature
elseif strcmp(beliefbias,'prior_mp2')==1 || strcmp(beliefbias,'prior_mp2_2types')==1 
    bwts = [puhb12;1-puhb12];
    bnodes = [eta_1b;eta_2b];
elseif strcmp(beliefbias,'prior_mp3')==1 || strcmp(beliefbias,'prior_mp3_3types')==1
    bwts = [puhb13;puhb23;1-puhb13-puhb23];
    bnodes = [eta_1b;eta_2b;eta_3b];
elseif strcmp(beliefbias,'prior_mp4')==1 || strcmp(beliefbias,'prior_mp4_4types')==1
    bwts = [puhb14;puhb24;puhb34;1-puhb14-puhb24-puhb34];
    bnodes = [eta_1b;eta_2b;eta_3b;eta_4b];
elseif strcmp(beliefbias,'prior_mp5')==1 || strcmp(beliefbias,'prior_mp5_5types')==1
    bwts = [puhb15;puhb25;puhb35;puhb45;1-puhb15-puhb25-puhb35-puhb45];
    bnodes = [eta_1b;eta_2b;eta_3b;eta_4b;eta_5b];
elseif strcmp(beliefbias,'prior_mp6')==1 || strcmp(beliefbias,'prior_mp6_6types')==1
    bwts = [puhb16;puhb26;puhb36;puhb46;puhb56;1-puhb16-puhb26-puhb36-puhb46-puhb56];
    bnodes = [eta_1b;eta_2b;eta_3b;eta_4b;eta_5b;eta_6b];
end
if strcmp(tasteuh,'mp2_nomu2_corr')==1 && strcmp(beliefbias,'prior_mp2_corr')==1
    twtsbwts = [p11 p12; 1-p11-p12-p22 p22];
    tnodes = [mu1;mu2];
    TNODES=2;
    bnodes = [eta_1b;eta_2b];
end


% Unobserved heterogeneity in taste for the job
alpha = tnodes(1)*(tastempdraw < twts(1));
for m=2:TNODES
    alpha = alpha + tnodes(m)* (tastempdraw > sum(twts(1:m-1))).* (tastempdraw <= sum(twts(1:m)));
end

if strcmp(substr(beliefbias,0,5),'prior')==1 && strcmp(beliefbias,'prior_normal_corr')~=1
    eta_b = bnodes(1)*(beliefmpdraw < bwts(1));
    for m=2:BNODES
        eta_b = eta_b + bnodes(m)* (beliefmpdraw > sum(bwts(1:m-1))).* (beliefmpdraw <= sum(bwts(1:m)));
    end
end

if strcmp(tasteuh,'mp2_2types')==1 || strcmp(tasteuh,'mp4_4types')==1 ...
    || strcmp(tasteuh,'mp6_6types')==1
    alpha = tnodes(1)*(tastempdraw < twts(1));
    eta_b = bnodes(1)*(tastempdraw < twts(1));
    for m=2:length(tnodes)
        alpha = alpha + tnodes(m)* (tastempdraw > sum(twts(1:m-1))).* (tastempdraw <= sum(twts(1:m)));
        eta_b = eta_b + bnodes(m)* (tastempdraw > sum(twts(1:m-1))).* (tastempdraw <= sum(twts(1:m)));
    end
end

% Dummies for who has which value of taste for job.
if exist('tnodes')
    dd_sim_tnodes = zeros(SIM_PERS,length(tnodes));
    for m=1:length(tnodes)
        dd_sim_tnodes(:,m)= (alpha==tnodes(m))*1;
    end
end

dd_sim_bnodes = zeros(SIM_PERS,BNODES);
for m=1:BNODES
    dd_sim_bnodes(:,m)= (eta_b==bnodes(m))*1;
end

% NODESBNODES = TNODES*BNODES;
% "n_m" is the counter for the taste UH nodes.
% "bn_m" is the counter for the belief nodes.
dd_sim_tnodesbnodes = zeros(SIM_PERS,TNODES*BNODES);
for m=1:TNODES*BNODES
    n_m = ceil(m/BNODES); 
    bn_m = mod(m,BNODES)*(mod(m,BNODES)~=0)+BNODES*(mod(m,BNODES)==0);
    dd_sim_tnodesbnodes(:,m)= (alpha==tnodes(n_m)).*(eta_b==bnodes(bn_m))*1;
end

% Simulate the random #s for non-discretized miles. We use the
% same seed as for the idiosyncratic shocks.
randn('state',SEED1);
earndraws = randn(SIM_PERS,NPER_SIM);

% Individual underlying ability is drawn from a Normal(eta0,sig0) distriubtion. 
eta = eta0 + sig_0*randn(SIM_PERS,1);

%{
3 properties of miles data:
(1) Miles or average miles.
(2) Regular or de-trended.
(3) Raw or gridded.
%}

% Raw simulated miles and average miles to date.
% In last line, we avoid using "mean" function for speed.
sim_earn_raw = zeros(SIM_PERS,NPER_SIM);
sim_mearn_raw = zeros(SIM_PERS,NPER_SIM);
sim_earn_raw(:,T_NOLEARN+1)= eta + atrend(T_NOLEARN+1)+sig_y*earndraws(:,T_NOLEARN+1);
sim_mearn_raw(:,T_NOLEARN+1)= sim_earn_raw(:,T_NOLEARN+1);
for t=T_NOLEARN+2:NPER_SIM
    tt=t-T_NOLEARN;
    sim_earn_raw(:,t)= eta + atrend(t)+ sig_y*earndraws(:,t);    
    sim_mearn_raw(:,t) = ((tt-1)*sim_mearn_raw(:,t-1) + sim_earn_raw(:,t))/tt;    
    % sim_mearn_raw(:,t) = mean(sim_earn_raw(:,T_NOLEARN+1:t),2);
end

% De-trended miles. Just remove the "atrend" from above.
sim_dt_earn_raw = zeros(SIM_PERS,NPER_SIM);
sim_dt_mearn_raw = zeros(SIM_PERS,NPER_SIM);
for t=T_NOLEARN+1:NPER_SIM
    sim_dt_earn_raw(:,t)= sim_earn_raw(:,t)-atrend(t);
    sim_dt_mearn_raw(:,t)= sim_mearn_raw(:,t)-amtrend(t);
end

% PUT MILES ON A GRID. Miles and averages miles, reg and de-trended.
sim_earn = zeros(SIM_PERS,NPER_SIM); 
sim_mearn = zeros(SIM_PERS,NPER_SIM); 
sim_dt_earn = zeros(SIM_PERS,NPER_SIM); 
sim_dt_mearn = zeros(SIM_PERS,NPER_SIM); 
% Assign to grid point one if below threshold one.
sim_earn = sim_earn + grid_ys(1)*(sim_earn_raw<=thres_ys(1));
sim_mearn = sim_mearn + grid_ys(1)*(sim_mearn_raw<=thres_ys(1));
sim_dt_earn = sim_dt_earn + grid_ys(1)*(sim_dt_earn_raw<=thres_ys(1));
sim_dt_mearn = sim_dt_mearn + grid_ys(1)*(sim_dt_mearn_raw<=thres_ys(1));
% Assign to grid point k if above thres (k-1) and below thres (k) 
for kX=2:NGRID
sim_earn = sim_earn + grid_ys(kX)*(sim_earn_raw>thres_ys(kX-1) & sim_earn_raw<=thres_ys(kX));
sim_mearn = sim_mearn + grid_ys(kX)*(sim_mearn_raw>thres_ys(kX-1) & sim_mearn_raw<=thres_ys(kX));
sim_dt_earn = sim_dt_earn + grid_ys(kX)*(sim_dt_earn_raw>thres_ys(kX-1) & sim_dt_earn_raw<=thres_ys(kX));
sim_dt_mearn = sim_dt_mearn + grid_ys(kX)*(sim_dt_mearn_raw>thres_ys(kX-1) & sim_dt_mearn_raw<=thres_ys(kX));
end
% During first 5 weeks, miles should still be 0.
sim_mearn(:,1:T_NOLEARN)=zeros(SIM_PERS,T_NOLEARN);
sim_earn(:,1:T_NOLEARN)=zeros(SIM_PERS,T_NOLEARN);
sim_dt_mearn(:,1:T_NOLEARN)=zeros(SIM_PERS,T_NOLEARN);
sim_dt_earn(:,1:T_NOLEARN)=zeros(SIM_PERS,T_NOLEARN);


%{
Workers are asked in t to predict miles in t+1.
PERIOD AFTER TRAINING: No signals, so prediction based on eta0 + bnodes(m).
MOST PERIODS: bt ~ N(Eb(y_t+1),sig_b). 
Use "sqrt(sig_b^2)" instead "sig_b" to prevent "sig_b" from going negative.
%}
belief_shocks = sig_b*randn(SIM_PERS,NPER_SIM);
sim_beliefs_raw = zeros(SIM_PERS,NPER_SIM);
sim_beliefs_raw(:,T_NOLEARN+1) = eta0 +atrend(T_NOLEARN+2)+ eta_b + belief_shocks(:,T_NOLEARN+1);
for t=T_NOLEARN+2:NPER-1
    sim_beliefs_raw(:,t) = atrend(t+1) + pred_y(gamma_b(t),eta0+eta_b,sim_dt_mearn_raw(:,t))+belief_shocks(:,t);
end
for t=NPER:NPER
    sim_beliefs_raw(:,t) = atrend(t) + pred_y(gamma_b(t),eta0+eta_b,sim_dt_mearn_raw(:,t))+belief_shocks(:,t);
end
if NPER_SIM>NPER
for t=NPER+1:NPER_SIM
    sim_beliefs_raw(:,t) = atrend(NPER) + pred_y(1,eta0+eta_b,sim_dt_mearn_raw(:,NPER))+belief_shocks(:,t);
end
end

% Transition matrix of *mean earnings* is called "mearn2mearn".
% It gives the probability of crossing states between t and t+1.
mearn2mearn=zeros(NGRID,NGRID,NPER,BNODES);
for m=1:BNODES
    for t=1:NPER
        mearn2mearn(:,:,t,m) = eye(NGRID);
    end
end
for m=1:BNODES
    for t=1+T_NOLEARN:NPER
        tt=t-T_NOLEARN;
        block_i = -(tt-1)*grid_ys - atrend(t)-pred_y(gamma_b(t-1),eta0+bnodes(m),grid_ys-amtrend(t-1));
        block_j = tt*thres_ys;
        block_1 = block_i + ones(NGRID,1)*block_j(1)';
        mearn2mearn(:,1,t,m) = normcdf(block_1 / omega_b(t));
        block_big = block_i*ones(1,NGRID-1) + ones(NGRID,1)*block_j(2:NGRID)';
        block_small = block_i*ones(1,NGRID-1) + ones(NGRID,1)*block_j(1:NGRID-1)';
        mearn2mearn(:,2:NGRID,t,m) = normcdf((block_big)/omega_b(t))-normcdf((block_small)/omega_b(t));
    end
end

%% "oowage" is the outside option wage for a worker.
oowage = ones(NPER,1)*rwage;
for t=1:T_NOLEARN
    oowage(t) = oowage(t)- ((T_NOLEARN+1-t)/T_NOLEARN)*v_ojt;
end
if strcmp(ootimetrend,'logit')==1
    oowage = oowage + 2*theta1*(-.5+LogitMH(theta2*(0:1:NPER-1)'));
end


%% "VQ_bar" is the choice-specific value fucntion associated with quitting 
VQ_bar = zeros(NPER+1,1);
% VQ_bar(1:NPER) are the time-indexed choice-specific value functions.
VQ_bar(1:NPER) = oowage/(1-delta);
% VQ_bar(NPER+1) is asymptotic value function. Outside option is 
% same as in period NPER.
VQ_bar(NPER+1) = oowage(NPER)/(1-delta);
% We also use "VQ_barinf" to denote asymptotic value function.
VQ_barinf = VQ_bar(NPER+1);


% Incorporate the quit penalties
VQ_bar(1:NPER) = VQ_bar(1:NPER) - kvector;


%% "VS_bar" is the choice-specific value fucntion associated with staying
VS_bar_full = zeros(TNODES*BNODES,NGRID,NPER+1,COVARSTATES); 
VS_barinf_full = zeros(NGRID,TNODES*BNODES,COVARSTATES);  

for rx = 1:COVARSTATES

% The inner loop tolerance is defined as an option.
VS_barinf = ones(NGRID,TNODES*BNODES);
diff_S = 1;
tnodesnew = [];
for m=1:TNODES
    tnodesnew = [tnodesnew repmat(tnodes(m),1,BNODES)];
end


while (diff_S>tol_InnerLoop)
    VS_barinf_new = (milepay(NPER)*(grid_ys-amtrend(NPER)+atrend(NPER)))*ones(1,TNODES*BNODES)...
    + ones(NGRID,1)*tnodesnew + delta*tau*log(exp(VS_barinf/tau)+exp(VQ_barinf/tau));   
    diff_S = max(max(abs(VS_barinf_new-VS_barinf)));
    VS_barinf = VS_barinf_new;
end

VS_barinf_full(:,:,rx) = VS_barinf; 


% EV(:,:,t) is the expected value or EMax of the choice-specific value 
% functions during period t: EV(:,:,t) = Emax(VM(t),VC(t)).
% The final period, NPER+1, is the period for the asymptotic value funcs.
EV=zeros(NGRID,TNODES*BNODES,NPER+1);
VS_bar = zeros(NGRID,TNODES*BNODES,NPER+1);
VS_bar(:,:,NPER+1)=VS_barinf;
EV(:,:,NPER+1)= tau*log(exp(VS_barinf/tau)+exp(VQ_barinf/tau));


% Start in period T (NPER). Then go backward until period T_NOLEARN+1.
% Last period done is tt=NPER+1-t=NPER+1-(NPER-T_NOLEARN)=T_NOLEARN+1.
for m=1:TNODES*BNODES
    n_m = ceil(m/BNODES); 
    bn_m = mod(m,BNODES)*(mod(m,BNODES)~=0)+BNODES*(mod(m,BNODES)==0); 
    for t=1:NPER-T_NOLEARN
        tt=NPER+1-t;
        VS_bar(:,m,tt)= milepay(tt)*(atrend(tt)+pred_y(gamma_b(tt-1),eta0+bnodes(bn_m),grid_ys-amtrend(tt-1)))...
            +tnodes(n_m)+delta*mearn2mearn(:,:,tt,bn_m)*EV(:,m,tt+1);               
        EV(:,m,tt)=tau*log(exp(VS_bar(:,m,tt)/tau)+exp(VQ_bar(tt)/tau));
    end
end

% Value functions during on-the-job training. As noted in FN, non-pecuniary
% taste for the job is zero during on-the-job training. Fit is similar
% if this is relaxed.
% VS_bar(:,m,tt)=TRAINING_PAY+tnodes(n_m)+delta*mearn2mearn(:,:,tt,bn_m)*EV(:,m,tt+1);
for m=1:TNODES*BNODES
    n_m = ceil(m/BNODES); 
    bn_m = mod(m,BNODES)*(mod(m,BNODES)~=0)+BNODES*(mod(m,BNODES)==0); 
    for t=1:T_NOLEARN
        tt=T_NOLEARN+1-t;
        VS_bar(:,m,tt)=TRAINING_PAY+delta*mearn2mearn(:,:,tt,bn_m)*EV(:,m,tt+1);
        EV(:,m,tt)=tau*log(exp(VS_bar(:,m,tt)/tau)+exp(VQ_bar(tt)/tau));
    end
end

% Convert VS_bar=zeros(NGRID,TNODES*BNODES,NPER+1) to VS_bar=zeros(TNODES*BNODES,NGRID,NPER+1)
VS_barsafe = VS_bar;
VS_bar = permute(VS_bar, [2 1 3]);
VS_bar_full(:,:,:,rx) = VS_bar;

end % This ends the statement: for rx=1:COVARSTATES
VS_bar = VS_bar_full;
VS_barinf = VS_barinf_full; 

% "dd_sim_mearn" is dummies for simulated, gridded avg miles.
% Preassigning speeds up dramatically
dd_sim_mearn = zeros(SIM_PERS,NGRID,NPER); 
for t=1:NPER
    for j=1:NGRID
        dd_sim_mearn(:,j,t)= (sim_mearn(:,t)==grid_ys(j))*1;
    end
end
% Assign everyone to middle of grid during no learning / on-the-job
% training. 
for t=1:T_NOLEARN
    dd_sim_mearn(:,round(length(grid_ys)/2),t)=ones(SIM_PERS,1);
end

% VS_bar is zeros(TNODES*BNODES,NGRID,NPER+1,COVARSTATES) 
% Convert (TNODES*BNODES,NGRID,NPER+1,COVARSTATES) to (TNODES*BNODES,NGRID,COVARSTATES, NPER+1) 
VS_bar = permute(VS_bar, [1 2 4 3]);

% "holder" is just intermediate object used in calculating "sim_stay".
holder = zeros(SIM_PERS,COVARSTATES);
for t=1:NPER
    for rx=1:COVARSTATES
        holder(:,rx)=( sum(dd_sim_mearn(:,:,t).*(dd_sim_tnodesbnodes*VS_bar(:,:,rx,t)),2) ...
            + sim_e1(:,t) >VQ_bar(t) + sim_e2(:,t))*1 ;
    end
    sim_stay(:,t,cfdraw) = sum(dd_sim_covars.*holder,2);
end

if exist('NPER_SIM') && NPER_SIM>NPER 
    for t=NPER+1:NPER_SIM
        for rx=1:COVARSTATES
            holder(:,rx)=(sum(dd_sim_mearn(:,:,NPER).*(dd_sim_tnodesbnodes*VS_barinf(:,:,rx)'),2) ...
                + sim_e1(:,t)>VQ_barinf+ sim_e2(:,t));
        end
        sim_stay(:,t,cfdraw)= sum(dd_sim_covars.*holder,2);
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Mean miles and beliefs over time with no selectivity.
sim_earn_raw_noselec = sim_earn_raw;
sim_mearn_raw_noselec = sim_mearn_raw;
sim_sumearn_noselec=[];
for t=T_NOLEARN+1:NDEC
     m_sim_earn_noselec = mean(sim_earn_raw(:,t));
     sim_sumearn_noselec = [sim_sumearn_noselec m_sim_earn_noselec];
end

sim_sumbeliefs_noselec=[];
for t=T_NOLEARN+1:NDEC
    m_sim_beliefs_noselec = mean(sim_beliefs_raw(:,t));
    sim_sumbeliefs_noselec = [sim_sumbeliefs_noselec m_sim_beliefs_noselec];
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Change `stay' decisions after a quit to -9
for t=2:NPER
    sim_stay(:,t,cfdraw)= (sim_stay(:,t,cfdraw).*(sim_stay(:,t-1,cfdraw)==1)) -9*((sim_stay(:,t-1,cfdraw)==0) + (sim_stay(:,t-1,cfdraw)==-9));
end
if exist('NPER_SIM') && NPER_SIM>NPER
    for t=NPER+1:NPER_SIM
        sim_stay(:,t,cfdraw)= (sim_stay(:,t,cfdraw).*(sim_stay(:,t-1,cfdraw)==1)) -9*((sim_stay(:,t-1,cfdraw)==0) + (sim_stay(:,t-1,cfdraw)==-9));
    end
end
    
% Change miles after a quit or missing to -9.
for t=2:NPER
sim_earn(:,t)= (sim_earn(:,t).*(sim_stay(:,t-1,cfdraw)==1))-9*(sim_stay(:,t-1,cfdraw)<=0);
sim_mearn(:,t)= (sim_mearn(:,t).*(sim_stay(:,t-1,cfdraw)==1))-9*(sim_stay(:,t-1,cfdraw)<=0);
sim_earn_raw(:,t)=(sim_earn_raw(:,t).*(sim_stay(:,t-1,cfdraw)==1))-9*(sim_stay(:,t-1,cfdraw)<=0);
sim_mearn_raw(:,t)= (sim_mearn_raw(:,t).*(sim_stay(:,t-1,cfdraw)==1))-9*(sim_stay(:,t-1,cfdraw)<=0);
sim_beliefs_raw(:,t)= (sim_beliefs_raw(:,t).*(sim_stay(:,t-1,cfdraw)==1))-9*(sim_stay(:,t-1,cfdraw)<=0);
end
if exist('NPER_SIM') && NPER_SIM>NPER 
for t=NPER+1:NPER_SIM
sim_earn(:,t)= (sim_earn(:,t).*(sim_stay(:,t-1,cfdraw)==1)) -9*(sim_stay(:,t-1,cfdraw)<=0);
sim_mearn(:,t)= (sim_mearn(:,t).*(sim_stay(:,t-1,cfdraw)==1)) -9*(sim_stay(:,t-1,cfdraw)<=0);
sim_earn_raw(:,t)= (sim_earn_raw(:,t).*(sim_stay(:,t-1,cfdraw)==1)) -9*(sim_stay(:,t-1,cfdraw)<=0);
sim_mearn_raw(:,t)= (sim_mearn_raw(:,t).*(sim_stay(:,t-1,cfdraw)==1)) -9*(sim_stay(:,t-1,cfdraw)<=0);
sim_beliefs_raw(:,t)= (sim_beliefs_raw(:,t).*(sim_stay(:,t-1,cfdraw)==1)) -9*(sim_stay(:,t-1,cfdraw)<=0);
end
end

% NPER x 1 matrix of simulated staying probs over time.
simpr_stayhaz=[];
for t=1:NPER
     m_simpr_one_stayhaz = sum(sim_stay(:,t,cfdraw).*(sim_stay(:,t,cfdraw)~=-9))/sum(1.*(sim_stay(:,t,cfdraw)~=-9));
     simpr_stayhaz = [simpr_stayhaz m_simpr_one_stayhaz];
end
simpr_stayhaz = simpr_stayhaz';
simpr_quithaz = 1-simpr_stayhaz;

% "simpr_surviv" is the simulated survival function.
if cfdraw==1 
    simpr_surviv = zeros(NPER,1);
    simpr_surviv(1)=simpr_stayhaz(1);
    for k=2:NPER
        simpr_surviv(k)=simpr_surviv(k-1)*simpr_stayhaz(k);
    end
    simpr_surviv = [1; simpr_surviv];
end

% "simpr_surviv_contrfac" is the simulated counterfactual survival func.
if cfdraw==2
    simpr_surviv_contrfac = zeros(NPER,1);
    simpr_surviv_contrfac(1)=simpr_stayhaz(1);
    for k=2:NPER
        simpr_surviv_contrfac(k)=simpr_surviv_contrfac(k-1)*simpr_stayhaz(k);
    end
    simpr_surviv_contrfac = [1; simpr_surviv_contrfac];      
end

end

if CFDRAWS==2
    sim_stay_contrfac = sim_stay(:,:,2);
end

sim_stay = sim_stay(:,:,1);

% Chi-squared stat for comparing actual vs. simulated quit hazard.
% "chisq" has dimension (NDEC+1) x 1. 
chisq = numbatrisk(1:NDEC).*((quithaz(1:NDEC) - simpr_quithaz(1:NDEC)).^2) ./ simpr_quithaz(1:NDEC);
% Chi-squared cell for last decision space, stay for whole time period.
% "surviv(t)" is the probabiliity of survival to start of week t.
chisq = [chisq ; numbatrisk(NDEC)*((surviv(NDEC+1)-simpr_surviv(NDEC+1))^2) ...
    / simpr_surviv(NDEC+1)]; 
p_chisq = 1-chi2cdf(chisq,1);

disp(' ');
disp('MODEL FOR INDIVIDUAL WEEKS');
disp('              ---------------------------- ');
disp('                Weeks Rejected        Total Weeks');
disp(['                '  num2str(sum((p_chisq<.05)*1)) '        ' num2str((NDEC+1))]);
disp(' ');
disp('MODEL FIT FOR ALL WEEKS COMBINED');
disp('              ---------------------------- ');
disp('                chi-squared stat        p-value');
disp(['                '  num2str(sum(chisq)) '        ' num2str(1-chi2cdf(sum(chisq),NDEC))]);

% The average of simulated raw miles over time.
sim_sumearn=[];
for t=T_NOLEARN+1:NDEC
     m_sim_one_earn = sum(sim_earn_raw(:,t).*(sim_stay(:,t)~=-9))/sum(1.*(sim_stay(:,t)~=-9));
     sim_sumearn = [sim_sumearn m_sim_one_earn];
end

% The average of simulated raw mile beliefs over time.
sim_sumbeliefs=[];
for t=T_NOLEARN+1:NDEC
    m_sim_one_beliefs = sum(sim_beliefs_raw(:,t).*(sim_stay(:,t)~=-9))/sum(1.*(sim_stay(:,t)~=-9));
    sim_sumbeliefs = [sim_sumbeliefs m_sim_one_beliefs];
end

%% Calculate profits and welfare under debiasing counterfactual
if strcmp(counterfactual,'elim_overconf')==1
    RegTrain = plot(0:NDEC,simpr_surviv(1:NDEC+1),0:NDEC,simpr_surviv_contrfac(1:NDEC+1));  
    title('Effect of Eliminating Overconfidence on Cumulative Retention')
    legend('Initial','Eliminate Overconfidence')
    xlabel('Week')
    ylabel('Cumulative retention')
    ylim([0 1])
    set(RegTrain,'LineWidth',2.5)        
    disp(' ');
    disp('EFFECTS OF CAMPAIGN TO ELIMINATE OVERCONFIDENCE'); 
    disp(' ');
    xx1 = [simpr_surviv_contrfac(tt1);simpr_surviv_contrfac(tt1)-simpr_surviv(tt1)];
    xx2 = [simpr_surviv_contrfac(tt2);simpr_surviv_contrfac(tt2)-simpr_surviv(tt2)];
    xx3 = [simpr_surviv_contrfac(tt3);simpr_surviv_contrfac(tt3)-simpr_surviv(tt3)];
    
    NEWNAMES{1,1}='Retention'; NEWNAMES{2,1}='Increased R';
    disp('                 20wks       40wks    60wks');
    for rX=1:2
        fprintf('%-10s %10.4f %10.4f %10.4f\n', NEWNAMES{rX,1}, [xx1(rX,1) xx2(rX,1) xx3(rX,1) ]);
    end
    
    % Matrices for discounting
    discountmat_worker = repmat(delta.^(0:1:NPER-1),SIM_PERS,1);
    discountmat_firm = repmat(delta_firm.^(0:1:NPER-1),SIM_PERS,1);
    if exist('NPER_SIM')
        discountmat_worker = repmat(delta.^(0:1:NPER_SIM-1),SIM_PERS,1);
        discountmat_firm = repmat(delta_firm.^(0:1:NPER_SIM-1),SIM_PERS,1);
    end
        
        
    % workerearnings is 'money' workers actually earn (includes outs opt)
    % workerutility is 'utility' workers actually acheieve
    
    % PUT COLLECTRATE IN FRONT OF DAMAGES
    % Removed COLLECTRATE IN FRONT OF DAMAGES FOR WORKER IN
    % workerearnings
    
    
 %%%% START ON CALCULATING WORKER UTILITY   
    if exist('NPER_SIM')==0 || NPER_SIM<=NPER
        
        % Four parts of worker earnings: (1) Driver pay, 
        % (2) outside pay, (3) quit penalties, and (4) training pay.                   
        
        % "quitwage" is level of outside option when someone quits.
        % It varies across people depending on when they quit.        
        quitwage = oowage(1)*(sim_stay_contrfac(:,1)==0);
        for t=2:NPER
            quitwage = quitwage + oowage(t)*(sim_stay_contrfac(:,t)==0);
        end
        % "quitearnings" is matrix of earnings following a quit.
        % These are earned in all the weeks when a driver is not staying 
        % (i.e., is either quitting or has quit in the past).        
        quitearnings = repmat(quitwage,1,NPER).*(sim_stay_contrfac~=1);   
        
        workerearnings = sim_earn_raw.*(sim_stay_contrfac==1).*(repmat(milepay',SIM_PERS,1)) ...
            +quitearnings ...
            -repmat(kvector',SIM_PERS,1).*(sim_stay_contrfac==0);    
        % Miles are 0 in the first 5 weeks except following a quit.
        workerearnings(:,1:T_NOLEARN)= workerearnings(:,1:T_NOLEARN)...
            +TRAINING_PAY*(sim_stay_contrfac(:,1:T_NOLEARN)==1);        
        
        % Three parts of worker utility: (1) Earnings, 
        % (2) Fixed taste for job, and (3) Transitory taste shocks.
        
        % Fixed taste for job
        worker_TUH = repmat(alpha,1,NPER).*(sim_stay_contrfac==1);
        % No taste utility during on-the-job training.
        worker_TUH(:,1:T_NOLEARN)=zeros(SIM_PERS,T_NOLEARN);
       
        % Transitory taste shocks
        worker_EPS = sim_e1.*(sim_stay_contrfac==1)+ sim_e2.*(sim_stay_contrfac==0);
        
        workerutility = workerearnings + worker_TUH + worker_EPS; 
    end
       
   
    if exist('NPER_SIM') && NPER_SIM>NPER
        
        % Add on extra weeks to components from above.
        oowage1 = [oowage;oowage(NPER)*ones(NPER_SIM-NPER,1)];
        milepay1 = [milepay;milepay(NPER)*ones(NPER_SIM-NPER,1)];
        kvector1 = [kvector;zeros(NPER_SIM-NPER,1)];
        margin1 = [margin;margin(NPER)*ones(NPER_SIM-NPER,1)];
               
        quitwage = oowage1(1)*(sim_stay_contrfac(:,1)==0);
        for t=2:NPER_SIM
            quitwage = quitwage + oowage1(t)*(sim_stay_contrfac(:,t)==0);
        end
        quitearnings = repmat(quitwage,1,NPER_SIM).*(sim_stay_contrfac~=1);
        
        workerearnings = sim_earn_raw.*(sim_stay_contrfac==1).*(repmat(milepay1',SIM_PERS,1)) ...
            +quitearnings ...
            -repmat(kvector1',SIM_PERS,1).*(sim_stay_contrfac==0);        
        workerearnings(:,1:T_NOLEARN)= workerearnings(:,1:T_NOLEARN)....
            +TRAINING_PAY*(sim_stay_contrfac(:,1:T_NOLEARN)==1);
        
        % Fixed taste for job. Experienced when driver stays.
        worker_TUH=repmat(alpha,1,NPER_SIM).*(sim_stay_contrfac==1);
        % No taste utility during on-the-job training.
        worker_TUH(:,1:T_NOLEARN)=zeros(SIM_PERS,T_NOLEARN);
        
        % Transitory taste shocks
        worker_EPS = sim_e1.*(sim_stay_contrfac==1)+ sim_e2.*(sim_stay_contrfac==0);
        
        workerutility = workerearnings + worker_TUH + worker_EPS;
    end
           
     %%%% START ON CALCULATING WORKER PROFITS     
    if exist('NPER_SIM')==0
        tkprofits = (sim_earn_raw.*repmat(margin',SIM_PERS,1)-FIXEDCOST).*(sim_stay_contrfac~=-9);
        damages = COLLECTRATE*repmat(kvector',SIM_PERS,1).*(sim_stay_contrfac==0);
    elseif exist('NPER_SIM')==1
        tkprofits = (sim_earn_raw.*repmat(margin1',SIM_PERS,1)-FIXEDCOST).*(sim_stay_contrfac~=-9);
        damages = COLLECTRATE*repmat(kvector1',SIM_PERS,1).*(sim_stay_contrfac==0);
    end
    
    % As noted in Appendix, profits during OJT are -TRAINING_PAY.
    tkprofits(:,1:T_NOLEARN)=-TRAINING_PAY*(sim_stay_contrfac(:,1:T_NOLEARN)~=-9);
            
    % PROFITS AND WORKER UTILTIY AFTER 'NPER_PROFIT_CALC' PERIODS.    
    tkprofits_profitcalc = sum(sum((tkprofits(:,1:NPER_PROFIT_CALC)+damages(:,1:NPER_PROFIT_CALC))...
        .*discountmat_firm(:,1:NPER_PROFIT_CALC)))-TRAINCOST*SIM_PERS;   
    workerutility_profitcalc = sum(sum(workerutility(:,1:NPER_PROFIT_CALC).*discountmat_worker(:,1:NPER_PROFIT_CALC)));
    
    % "ppw" = profits per worker. "upw" = utility per worker.
    % Multiple by 100 to convert to actual dollars.
    ppw = (100/SIM_PERS)*tkprofits_profitcalc;
    upw = (100/SIM_PERS)*workerutility_profitcalc;
    
    NAMESLIST{1,1}='Profits per Worker at 110 Weeks';     	
    NAMESLIST{2,1}='Welfare per Worker at 110 Weeks';    
    disp(' ');
    fprintf('%-10s %10.4f\n', NAMESLIST{1,1}, ppw);
    fprintf('%-10s %10.4f\n', NAMESLIST{2,1}, upw);
    disp(' '); 
        
    % Final worker utility and profits over all periods.
    % Not used for anything except mentioned in FN in Section 5.
    ppw_alltime = (100/SIM_PERS)*sum(sum(tkprofits.*discountmat_firm));
    upw_alltime = (100/SIM_PERS)*sum(sum(workerutility.*discountmat_worker));
       
end

%%  Figure F1: TENURE AND DISTRIBUTION OF PRODUCTIVITY
if strcmp(counterfactual,'none')==1 && strcmp(beliefbias, 'prior')==1 ...
    && strcmp(timetrend, 'logit')==1
sim_earnings_dist = zeros(length(grid_ys),NPER); 
sim_cumearnings_dist= zeros(length(grid_ys),NPER);
for t=1:NPER
    for i=1:length(grid_ys)
        sim_earnings_dist(i,t)=(sum(sim_earn(:,t)==grid_ys(i)))/sum(sim_earn(:,t)>0);
    end
    sim_cumearnings_dist(:,t)=cumsum(sim_earnings_dist(:,t));
end
figure(1)
index = 100*grid_ys(1:length(grid_ys));
G10 = subplot(1,1,1); 
plot(index,cumearnings_dist(:,10),':',index,sim_cumearnings_dist(:,10),'linewidth',4);
ylim([0 1])
xticks(0:1000:4000)
yticks(0:.2:1)
NameG10 =strcat('../../Writeup/Figures/Fig-TenProdDist-10w-',ParamsName,'-',time_now,'.pdf');
saveas(G10, NameG10);
G30 = subplot(1,1,1); 
plot(index,cumearnings_dist(:,30),':',index,sim_cumearnings_dist(:,30),'linewidth',4);
ylim([0 1])
xticks(0:1000:4000)
yticks(0:.2:1)
NameG30 =strcat('../../Writeup/Figures/Fig-TenProdDist-30w-',ParamsName,'-',time_now,'.pdf');
saveas(G30, NameG30);
G50 = subplot(1,1,1); 
plot(index,cumearnings_dist(:,50),':',index,sim_cumearnings_dist(:,50),'linewidth',4);
ylim([0 1])
xticks(0:1000:4000)
yticks(0:.2:1)
NameG50 =strcat('../../Writeup/Figures/Fig-TenProdDist-50w-',ParamsName,'-',time_now,'.pdf');
saveas(G50, NameG50);
G70 = subplot(1,1,1); 
plot(index,cumearnings_dist(:,70),':',index,sim_cumearnings_dist(:,70),'linewidth',4);
ylim([0 1])
xticks(0:1000:4000)
yticks(0:.2:1)
NameG70 =strcat('../../Writeup/Figures/Fig-TenProdDist-70w-',ParamsName,'-',time_now,'.pdf');
saveas(G70, NameG70);
end

%% CENTRAL PLOT, 4 SQUARES
LineWidthVal = 2.5;
% In this plot, because we start at week 0, survival shown at week t 
% is the share of workers who survive from quitting to the end of week t.
Survival=subplot(221); plot(0:NDEC,surviv,':',0:NDEC,simpr_surviv(1:NDEC+1),'LineWidth',LineWidthVal);
title('Survival from quitting')
xlabel('Week')
xlim([0 115])
ylim([0 1])
xticks(0:20:100)
yticks(0:.2:1)
h_legend=legend('Data','Model','location','best');
set(h_legend,'FontSize',6)
Hazard=subplot(222); plot(1:NDEC,quithaz_sm(1:NDEC),':',1:NDEC,simpr_quithaz(1:NDEC),'LineWidth',LineWidthVal)
title('Quit hazard')
xlabel('Week')
xlim([0 115])
ylim([0 .05])
xticks(0:20:100)
yticks(0:.01:.05)
h_legend=legend('Data','Model','location','best');
set(h_legend,'FontSize',6);
EarnTen=subplot(223);plot(T_NOLEARN+1:NDEC,100*sumearn_sm,':',T_NOLEARN+1:NDEC,100*sim_sumearn,'LineWidth', LineWidthVal)
title('Mean productivity')
xlabel('Week')
ylabel('Miles')
xlim([0 115])
ylim([1500 3000])
xticks(0:20:100)
yticks(1500:500:3000)
h_legend=legend('Data','Model','location','best');
set(h_legend,'FontSize',6);
BeliefsTen =subplot(224);plot(T_NOLEARN+1:NDEC,100*sumbeliefs_sm,':',T_NOLEARN+1:NDEC,100*sim_sumbeliefs,'LineWidth',LineWidthVal)
title('Mean beliefs')
xlabel('Week')
ylabel('Miles')
xlim([0 115])
ylim([1500 3000])
xticks(0:20:100)
yticks(1500:500:3000)
h_legend=legend('Data','Model','location','best');
set(h_legend,'FontSize',6);
NameFig4S=strcat('../../Writeup/Figures/Fig-4S-',ParamsName,'-',time_now,'.pdf');
if overconf_factor==1 && strcmp(counterfactual,'none')==1 
    saveas(Survival,NameFig4S);
end
toc;

%% Table 6: Results of Debiasing Counterfactuals
if strcmp(counterfactual,'elim_overconf')==1 
% The number "7" is just a placeholder to visually separate profits 
% and welfare from retention rates.
ZResults = [ppw;upw;7;simpr_surviv_contrfac(tt1);simpr_surviv_contrfac(tt2);simpr_surviv_contrfac(tt3)];
T6 = table(ZResults);
XLName_T6 = strcat('Estimates/Debiasing/Debiasing_', EstimatesName,'_',time_now,'.xlsx');
if overconf_factor == 1
    writetable(T6,XLName_T6,'Range','A1:A7');
elseif overconf_factor == .5
    writetable(T6,XLName_T6,'Range','B1:B7');
elseif overconf_factor==zero_overconf     
    writetable(T6,XLName_T6,'Range','C1:C7'); 
end    
end



%% Save chi-squared in .xlsx files. Only need for Table 4 estimates.
if strcmp(counterfactual,'none')==1
    Chi2Name=strcat('Estimates/', 'Chi2_', EstimatesName,time_now);
    XLName_Chi2 = strcat(Chi2Name,'.xlsx');
    T2 = table(sum(chisq));
    writetable(T2,XLName_Chi2);
end

%profile viewer