%{
====================================================
File name: read_data.m
Project: Overconfidence in trucking
Description: Reads in data and does structural estimation.

Key parts of file:
1. Read in data & specify key model assumptions.
2. Set options.
3. Set names and starting values based on options.
4. Specify variables from the data.
5. Do minimization.
====================================================
%}
set_globals;

%diary off
%diary Logit.out
cd Log
diary(strcat('OC_',EstimatesName,'_',time_now,'.log'))
cd ..

% TITLE
% Put a title for the run in the quotes below, to be printed at the top of the output file.
disp(' ');
disp('----------------------------')
disp 'Trucking Retention Model')
disp('----------------------------')
disp(' ');

%% 1. READ IN DATA & SPECIFY KEY MODEL ASSUMPTIONS

% Data names: see "zz_std_options.m" for datasets.
dataname = op.dataname;
data = load(dataname);

% NOBS is the number of people in the data
DATA_DIM= size(data);
NOBS=DATA_DIM(1);

% Number of decisions of data THAT WE USE FOR MAXIMUM LIKELIHOOD
NDEC=110;

% Actual number of decision in the data
NDEC_DATA = 110;

% Initial periods with no learning.
T_NOLEARN=5; 

%% 2. SET OPTIONS

% What variable is learning on?
learnover = op.learnover;

% Specify the mileage grid. Set in "zz_std_options.m"
grid_ys = op.grid_ys;

NGRID = length(grid_ys);
MINGRID = min(grid_ys); 
MAXGRID = max(grid_ys);

% Assumed discount rate, in a weekly format.
delta = op.delta;

% Baseline: 'baseline','earn_params_only','LBD_only'
% 'earn&belief_params_only'
% '2stage' means estimate earning parameters in first round.
baseline = op.baseline;

if strcmp(baseline,'baseline')==1
    NBASEPARAMS = 5;
end
if strcmp(baseline,'earn_params_only')==1 || strcmp(baseline,'earn&belief_params_only')==1
    NBASEPARAMS = 3;
end

if strcmp(baseline,'2stage')==1
    NBASEPARAMS = 1;
end

% Learning: 'no', 'normal'
op.learning = 'normal';
learning = op.learning;

% Belief about the speed of learning: Set in master.m
%{
'standard' = speed of learning determined by variation in miles or earnings
'general' = allows for a sigma_y_tilda; THIS IS MAIN APPROACH WE USE
%}
learnspeed = op.learnspeed;

% Time trend: 'no', 'logit', 'logit_firststage'. Set in master.m
timetrend = op.timetrend;

% First 5 week correction. Set in master.m
%{
Skill accumulation during 5 weeks of on-the-job training. 
~ 'first5'= allow for outside option to increase during the first 
5 weeks of training.
~ 'no_first5' = no correction during first 5 weeks.
%}
first5 = op.first5;

% Outside time trend: How does tenure affect your outside earnings? 
% Options: 'no', 'logit' (more ops in prior vers). Set in Master.m.
ootimetrend = op.ootimetrend;

% Covariates in taste for job: 'no_covars', 'college&old','ref1'.
op.covariates = 'no_covars';
covariates = op.covariates;

% Unobserved heterogeneity in taste for the job.
tasteuh = op.tasteuh;
MU2NUMBER =200; % Change if select masspoint2_uh_nomu2

% tasteuhprobrestrict: Whether restrict taste uh probs to (0,1).
tasteuhprobrestrict = op.tasteuhprobrestrict;

% Integration nodes for unobserved heterogeneity in taste for job
TNODES=3;

% Training contract faced. Set in "zz_std_options.m".
contract = op.contract;

% Go to separate script with pay per mile. CONFIDENTIAL INFO.
if strcmp(op.learnover,'miles')==1
      set_mile_pay; 
end

% Using the belief data to model a potential belief bias.
% This part here is the eta_b, or the mean bias in the prior.
beliefbias = op.beliefbias;

% Whether restrict belief bias probs to be in (0,1): 'no' or 'yes'.
op.beliefbiasprobrestrict = 'no';
beliefbiasprobrestrict = op.beliefbiasprobrestrict;

% Threshold for highest belief level. Set in "zz_std_options.m".
BELIEFTHRES = op.BELIEFTHRES;

% Thres for belief Winsorization threshold. Set in "zz_std_options.m".
WINSTHRES = op.WINSTHRES;

% Choice of solver: Set in "zz_std_options.m".
solver = op.solver;

% Integration nodes for unobserved heterogeneity in belief bias eta_b
BNODES=1;
if strcmp(beliefbias,'prior_normal')==1 || strcmp(beliefbias,'prior_normal_corr')==1
    BNODES=3;
elseif strcmp(beliefbias,'prior_mp2')==1 || strcmp(beliefbias,'prior_mp2_corr')==1 ...
        || strcmp(beliefbias,'prior_mp2_2types')==1
    BNODES=2;
elseif strcmp(beliefbias,'prior_mp3')==1 || strcmp(beliefbias,'prior_mp3_3types')==1
    BNODES=3;
elseif strcmp(beliefbias,'prior_mp4')==1 || strcmp(beliefbias,'prior_mp4_4types')==1
    BNODES=4;
elseif strcmp(beliefbias,'prior_mp5')==1 || strcmp(beliefbias,'prior_mp5_5types')==1
    BNODES=5;
elseif strcmp(beliefbias,'prior_mp6')==1 || strcmp(beliefbias,'prior_mp6_6types')==1
    BNODES=6;
end

% Runmode: If no mode is specified, it is in estimation mode.
% 'test_mode' is for debugging.
%runmode = 'test_mode';

% Profilers: 'no_profiler', 'profiler'
profiler = 'no_profiler';

if strcmp(profiler,'profiler')==1
    profile on;
end


%% 3. SET NAMES, STARTING VALUES, AND OPTIMIZATION OPTIONS.
if strcmp(baseline,'LBD_only')~=1 
    set_names_stvals;
elseif strcmp(baseline,'LBD_only')==1
    NAMES = {'a1';'a2'};
    STARTING = [2;.1];
end
        
    
%% OPTIMIZATION 
% Max iterations for optimization routine. Set in "zz_std_options.m".
MAXITERS = op.MAXITERS;

% Convergence criterion based on change in the log-likelihood that is
% considered to represent convergence. Set in "zz_std_options.m". 
LLTOL = op.LLTOL;

% Separate LLTOL for "fminsearch".
LLTOL_FMS = op.LLTOL_FMS;

% Separate LLTOL for "simulannealbnd" (i.e., simulated annealing).
LLTOL_SA = op.LLTOL_SA;

% X-TOLERANCE.
PARAMTOL = op.PARAMTOL;

% Tolerance for the inner loop
%{
Tolerance for the inner loop in the Rust (1987) procedure. We
want to set it small to know that we have well-approximated the value 
functions. We use a value in line with Dube, Fox, and Su (2012).
%}
op.tol_InnerLoop = 1e-15;
tol_InnerLoop = op.tol_InnerLoop;

% Lower bound on levels of unobserved heterogeneity.
MU_LB_BASE = op.MU_LB_BASE;
MU_LB_LBD  = op.MU_LB_LBD;

% Construct threshold grid to assign continuous values
% to points on the grid. These are half-way between
% the different grid points.
thres_ys = zeros(length(grid_ys),1);
for i=1:length(thres_ys)-1
    thres_ys(i) = .5*(grid_ys(i)+grid_ys(i+1));
end
thres_ys(length(grid_ys))=99999;


%% 4. SPECIFY VARIABLES FROM THE DATA.
% Four key elements of data: 
% (1) Attrition, (2) Earnings, (3) Mean earnings, (4) Beliefs.

% Dummies for staying each week
stay = data(:,2:NDEC+1); 

% Miles driven each week.
% We refer to the data as being on earnings instead of miles
% as we have also estimated the data using earnings data.
earn_raw = data(:,NDEC_DATA+2:NDEC_DATA+NDEC+1 );

% Mean miles per week.
mearn_raw = data(:,2*NDEC_DATA+2:2*NDEC_DATA+NDEC+1);

% Belief in t about miles to drive in t+1
beliefs_raw = data(:,3*NDEC_DATA+2:3*NDEC_DATA+NDEC+1);

% Divide by 100, and set missing to -9.
earn_raw = (earn_raw/100).*(1*(earn_raw~=-9))-9*(earn_raw==-9);
mearn_raw = (mearn_raw/100).*(1*(mearn_raw~=-9))-9*(mearn_raw==-9);

% Test that "mearn_raw" is always positive or -9.
assert(sum(sum(mearn_raw<=0 & mearn_raw~=-9))==0)

% If beliefs are above the trimming threshold, set to missing.
% Next, if beliefs are above the Winsorization threshold, set to threshold.
% If beliefs are missing, set to -9.
beliefs_raw = beliefs_raw.*(beliefs_raw<=BELIEFTHRES)-9*(beliefs_raw>BELIEFTHRES); 
beliefs_raw = beliefs_raw.*(beliefs_raw<=WINSTHRES)+WINSTHRES*(beliefs_raw>WINSTHRES);
beliefs_raw = (beliefs_raw/100).*(1*(beliefs_raw~=-9))-9*(beliefs_raw==-9);

% Convert miles and average miles to values on a grid.
% De-trended miles on the grid.
earn = -9*(earn_raw==-9); mearn = -9*(mearn_raw==-9);
% Assign to grid point one if positive miles and below threshold one.
for tX=1+T_NOLEARN:NDEC
earn(:,tX)= earn(:,tX) + grid_ys(1)*(earn_raw(:,tX)>0 & earn_raw(:,tX)<=thres_ys(1)).*ones(NOBS,1);
mearn(:,tX)= mearn(:,tX) + grid_ys(1)*(mearn_raw(:,tX)>0 & mearn_raw(:,tX)<=thres_ys(1)).*ones(NOBS,1);
end
% Assign to grid point k if above thres (k-1) and below thres (k).
for tX=1+T_NOLEARN:NDEC
for k=2:NGRID
earn(:,tX)= earn(:,tX) + grid_ys(k)*(earn_raw(:,tX)>thres_ys(k-1) & earn_raw(:,tX)<=thres_ys(k)).*ones(NOBS,1);
mearn(:,tX)=mearn(:,tX)+ grid_ys(k)*(mearn_raw(:,tX)>thres_ys(k-1) & mearn_raw(:,tX)<=thres_ys(k)).*ones(NOBS,1);
end
end

% Dummies for a person's gridded mean miles at a given time.
% E.g., if N=1 and K=3, dd_mearn might be [0 1 0] at time t.
dd_mearn = zeros(NOBS,NGRID,NPER);
for t=1:NDEC
    for j=1:NGRID
        dd_mearn(:,j,t)= (mearn(:,t)==grid_ys(j))*1;
    end
end
for t=1:T_NOLEARN
    dd_mearn(:,round(length(grid_ys)/2),t)=ones(NOBS,1);
end

% Covariates.
NVARS = min(size(data));
age = data(:,NVARS);
old = (age>=35)*1;
education = data(:,NVARS-1);
college = ((education==3) + (education==4))*1;
% Data are dummies for whether iq, patience, numeracy are above-median.
iq = data(:,NVARS-2);
patience = data(:,NVARS-3);
numeracy = data(:,NVARS-4);
female = data(:,NVARS-5);
hispanic = data(:,NVARS-6); 
black = data(:,NVARS-7);
ref1 = data(:,NVARS-8); 
schooling=(education==1)*9+(education==2)*12 ...
    +(education==3)*14 + (education==4)*16; 

% Inverse probability weighting to correct for non-response in belief data
ipw = op.ipw;
if strcmp(ipw,'yes')==1
    timesrespond = sum(beliefs_raw~=-9,2);
    everrespond = (timesrespond~=0);
    Xs = [ones(NOBS,1) black hispanic female age schooling iq patience];
    STARTINGPROB = [-1;0;0;0;.03;.03;.01;.01];
    options=optimset('LargeScale','off','Display','iter','GradObj','off',...
        'MaxFunEvals',10000,'MaxIter',MAXITERS,'TolX',PARAMTOL,'TolFun',LLTOL,'DerivativeCheck','off');
    probitcoef=fminunc(@ProbitMH,STARTINGPROB,options);
    pred_respond = normcdf(Xs*probitcoef);
elseif strcmp(ipw,'yes')==0
    pred_respond = ones(NOBS,1);
end

% Number of binary covariates, and extra rows from bivariate covariates
NBICOVARS=0;
if strcmp(covariates,'ref1')
    NBICOVARS=1;
elseif strcmp(covariates,'college&age')
    NBICOVARS=2;
end

COVARSTATES = 2^NBICOVARS;
dd_covars = ones(NOBS,1);
if strcmp(covariates,'ref1')
    dd_covars = [1*(ref1==0) 1*(ref1==1)];
elseif strcmp(covariates,'college&age')
    dd_covars = [1*(college==0).*(old==0) 1*(college==0).*(old==1)...
        1*(college==1).*(old==0) 1*(college==1).*(old==1)];
end


%% Display
date
disp(' ');
op
disp(' ');


%% Maximization options
NPARAMS = length(STARTING);
DisplayOpt = 'iter';

options_fminunc=optimset('LargeScale','off','Display',DisplayOpt,...
    'GradObj','off','MaxFunEvals',10000,'MaxIter',MAXITERS,...
    'TolX',PARAMTOL,'TolFun',LLTOL,'DerivativeCheck','off');

options_fmincon  = optimoptions(@fmincon,'Display','iter',...
    'MaxFunEvals',10000,'MaxIter',MAXITERS,...
    'TolX',PARAMTOL,'TolFun',LLTOL);

% Allow for more iterations with "fminsearch". 
options_fminsearch=optimset('Display',DisplayOpt,'MaxFunEvals',1.5e4,...
    'MaxIter',1.5e4,'TolX',PARAMTOL,'TolFun',LLTOL_FMS);

%{
options_SA  = optimoptions(@simulannealbnd,'Display',DisplayOpt,...
    'MaxFunEvals',1e6,'MaxIter',1e6,...
    'TolFun',LLTOL_SA,'InitialTemperature',1e2);
    %'PlotFcns',{@saplotbestx,@saplotbestf,@saplotx,@saplotf});
%}
    
if strcmp(solver,'fmincon')==1 || strcmp(solver,'fmincon&fminunc')==1
    AK=zeros(length(STARTING),length(STARTING)); 
    BK=zeros(length(STARTING),1);
    if strcmp(timetrend,'no')==1
        AK(6:8,6:8)=-eye(3);
        BK(6:8)=-op.MU_LB_BASE;
        LBM=[];
    end        
end

%% fminunc Estimation
warning off
if strcmp(solver,'fminunc')==1
    tic;
    [paramhat,fval,exitflag,output,grad,hessian]=fminunc(@loglik_OC,STARTING,options_fminunc);
    toc;
    ihess=inv(hessian);
    stderr=sqrt(diag(ihess));
    [ses_bhhh,grad_MH]=doit_bhhh(paramhat);
end

%% fmincon Estimation
warning off
if strcmp(solver,'fmincon')==1
    tic;
    [paramhat,fval,exitflag,output,lambda,grad,hessian]=fmincon(@loglik_OC,STARTING,AK,BK,[],[],LBM,[],[],options_fmincon);
    toc;
    ihess=inv(hessian);
    stderr=sqrt(diag(ihess));
    [ses_bhhh,grad_MH]=doit_bhhh(paramhat);
end


if strcmp(solver,'fmincon&fminunc')==1
    tic;
    [paramhat,fval,exitflag,output,lambda,grad,hessian]=fmincon(@loglik_OC,STARTING,AK,BK,[],[],LBM,[],[],options_fmincon);
    [paramhat,fval,exitflag,output,grad,hessian]=fminunc(@loglik_OC,paramhat,options_fminunc);
    toc;
    ihess=inv(hessian);
    stderr=sqrt(diag(ihess));
    [ses_bhhh,grad_MH]=doit_bhhh(paramhat);
end


%% fminsearch estimator
if strcmp(solver,'fminsearch')==1
    tic;
    [paramhat,fval,exitflag,output]=fminsearch(@loglik_OC,STARTING,options_fminsearch);
    toc;
    [ses_bhhh,grad_MH]=doit_bhhh(paramhat);
    hessian_JD = HessianJD(@loglik_OC,paramhat);
end

% "fminunc" followedby "fminsearch".
if strcmp(solver,'fminunc&fminsearch')==1  
    tic;
    [paramhat,fval,exitflag]=fminunc(@loglik_OC,STARTING,options_fminunc);
        EstName4S=strcat('Estimates/', 'Intermed_', EstimatesName,'_',time_now);
        save(EstName4S,'paramhat','NAMES','op','fval','exitflag','STARTING');
    [paramhat,fval,exitflag,output]=fminsearch(@loglik_OC,paramhat,options_fminsearch);
    toc;
    [ses_bhhh,grad_MH]=doit_bhhh(paramhat);
    hessian_JD = HessianJD(@loglik_OC,paramhat);
end


%% Simulated annealing

% Simulated annealing
if strcmp(solver,'SA')==1  
    tic;
    rng default % For reproducibility
    [paramhat,fval,exitflag,output]=simulannealbnd(@loglik_OC,STARTING,-99999,999999,options_SA);
    toc;
    [ses_bhhh,grad_MH]=doit_bhhh(paramhat);
    hessian_JD = HessianJD(@loglik_OC,paramhat);
end

% "fminunc" followed by simulated annealing.
if strcmp(solver,'fminunc&SA')==1  
    tic;
    [paramhat]=fminunc(@loglik_OC,STARTING,options_fminunc);
    rng default % For reproducibility
    [paramhat,fval,exitflag,output]=simulannealbnd(@loglik_OC,paramhat,-99999,999999,options_SA);
    toc;
    [ses_bhhh,grad_MH]=doit_bhhh(paramhat);
    hessian_JD = HessianJD(@loglik_OC,paramhat);
end


%% Results
LL = -fval;
AIC = -2*LL + 2*NPARAMS;
BIC = -2*LL + log(NOBS)*NPARAMS;


if strcmp(solver,'fminunc')==1 || strcmp(solver,'fmincon')==1 ...
    || strcmp(solver,'fmincon&fminunc')==1
    g_inf = max(abs(grad));
    gHg = grad'*ihess*grad;
    Min_Eig = min(eig(hessian));
    Kappa_H = max(eig(hessian))/min(eig(hessian));    
elseif strcmp(solver,'fminunc')~=1 && strcmp(solver,'fmincon')~=1 ...
    && strcmp(solver,'fmincon&fminunc')~=1
    g_inf = max(abs(grad_MH));
    gHg = grad_MH'*inv(hessian_JD)*grad_MH;
    Min_Eig = min(eig(hessian_JD));
    Kappa_H = max(eig(hessian_JD))/min(eig(hessian_JD));
end
    


disp(' ');
disp(['Data Used: ' dataname]);
disp(['Contract option assumed: ' num2str(contract)]);
disp(['Learning assumption: ' learning]);
disp(['Time trend: ' timetrend]);
disp(['Taste unobserved heterogeneiety: ' tasteuh]);
disp(['Skill acquisition in initial periods: ' first5]);
disp(['Belief bias: ' beliefbias]);
disp(' ');
disp(['Number of periods assumed in structural model (NPER): ' num2str(NPER)]);
disp(['Number of periods of available data (NDEC_DATA): ' num2str(NDEC_DATA)]);
disp(['Number of periods of data used (NDEC): ' num2str(NDEC)]);
disp(['Assumed annualized discount factor: ' num2str(delta^52)]);

   
if strcmp(solver,'fminunc')==1
NVARS=size(NAMES,1);
disp(' ');
disp('ESTIMATION RESULTS');
disp('              ---------------------------- ');
disp('                Est         SE      t-stat');
for r=1:NVARS
    if strcmp(NAMES(r),'delta')==0
        fprintf('%-10s %10.4f %10.4f %10.4f\n', NAMES{r,1}, [100*paramhat(r,1) 100*stderr(r,1) paramhat(r,1)./stderr(r,1) ]);
    elseif strcmp(NAMES(r),'delta')==1
        fprintf('%-10s %10.4f %10.4f %10.4f\n', NAMES{r,1}, [paramhat(r,1) stderr(r,1) paramhat(r,1)./stderr(r,1) ]);
    end
end
disp(' ');
disp(['LL: ' num2str(LL)]);
disp(['AIC: ' num2str(AIC)]);
disp(['BIC: ' num2str(BIC)]);
disp(' ');
end

disp(' ');
disp(['Inf norm of the gradient: ' num2str(g_inf)]);
disp(['Knittel-Metaxoglou stopping criterion: ' num2str(gHg)]);


if strcmp(profiler,'profiler')==1
    profile viewer
end

disp(' ');
disp('----------------------------')
disp('End of Results')
disp('----------------------------')
disp(' ');

%% Create version of data that can be taken to Excel
NAMES_XL = NAMES(2:end);
NAMES_XL = [NAMES_XL; NAMES(1)]; 
paramhat_XL = paramhat(2:end);
paramhat_XL = [paramhat_XL; paramhat(1)]; 
% For baseline, use SEs from inverting the Hessian.
% For results with learning by doing, use BHHH std errors.
if strcmp(op.timetrend,'no')==1 && (strcmp(solver,'fminunc')==1 || strcmp(solver,'fmincon&fminunc')==1)
    stderr_XL = stderr(2:end);
    stderr_XL = [stderr_XL; stderr(1)]; 
elseif strcmp(op.timetrend,'logit')==1 || strcmp(op.timetrend,'logit_firststage')==1 ...
    || ( strcmp(solver,'fminunc')~=1 && strcmp(solver,'fmincon&fminunc')~=1)
    stderr_XL = ses_bhhh(2:end);
    stderr_XL = [stderr_XL; ses_bhhh(1)]; 
end
XLEst = zeros(2*length(paramhat_XL),1);
XLNames = strings(2*length(paramhat_XL),1);
for iX=1:length(paramhat_XL)
    XLNames(2*iX-1,1)= NAMES_XL(iX);    
    if string(NAMES_XL(iX))~='puh13' &&  string(NAMES_XL(iX))~='puh23' ... 
            && string(NAMES_XL(iX))~='theta2' && string(NAMES_XL(iX))~='a2' 
        XLEst(2*iX-1,1)= 100*paramhat_XL(iX,1);
        XLEst(2*iX,1)=   100*stderr_XL(iX,1);
    elseif string(NAMES_XL(iX))=='theta2' || string(NAMES_XL(iX))=='a2' 
        XLEst(2*iX-1,1)= paramhat_XL(iX,1);
        XLEst(2*iX,1)=   stderr_XL(iX,1);
    elseif (string(NAMES_XL(iX))=='puh13' || string(NAMES_XL(iX))=='puh23') ...
            && strcmp(op.tasteuhprobrestrict,'no')==1
        XLEst(2*iX-1,1)= paramhat_XL(iX,1);
        XLEst(2*iX,1)=   stderr_XL(iX,1);
    elseif (string(NAMES_XL(iX))=='puh13' || string(NAMES_XL(iX))=='puh23') ...
            && strcmp(op.tasteuhprobrestrict,'yes')==1
        XLEst(2*iX-1,1)= LogitMH(paramhat_XL(iX,1));
        XLEst(2*iX,1)=   (stderr_XL(iX,1))*(exp(paramhat_XL(iX,1)))/(1+(exp(paramhat_XL(iX,1)))^2);  
    end
end
XLEst = [XLEst;LL;length(data);exitflag;g_inf;gHg;Min_Eig;Kappa_H];
XLNames = [XLNames;'LL';'N';'Exit Flag'; 'L_inf gradient';'KM stopping criterion';...
    'Min Hessian Eigenvalue';'Kappa_H'];


%% Save parameter estimates and estimation info in .mat and .xlsx files
EstName4S=strcat('Estimates/', EstimatesName,'_',time_now);

if strcmp(solver,'fminunc')==1 || strcmp(solver,'fmincon')==1 || strcmp(solver,'fmincon&fminunc')==1
    save(EstName4S,'paramhat','grad','hessian','stderr','LL','AIC','BIC','NAMES',...
        'op','exitflag','ses_bhhh','STARTING','XLEst','g_inf','gHg','Min_Eig','Kappa_H');
end
if strcmp(solver,'fminunc')~=1 && strcmp(solver,'fmincon')~=1 && strcmp(solver,'fmincon&fminunc')~=1
    save(EstName4S,'paramhat','NAMES','op','exitflag','ses_bhhh','LL','STARTING','XLEst',...
        'grad_MH','g_inf','gHg','Min_Eig','Kappa_H');
end


% Save estimated parameters in .xlsx files
XLName = strcat(EstName4S,'.xlsx');
T = table([XLNames XLEst]);
writetable(T,XLName);


%% Specify parameters use for rest of code
ParamsName = EstimatesName;


zz=load(EstName4S,'paramhat');
paramhat = zz.paramhat;


