%{
====================================================
Script name: set_names_stvals.m
Modified: January 2019
Project: Overconfidence
Description: Set starting values and parameter names 
based on options.

Key parts:
- Baseline parameters.
- Skill accumulation at outside option.
- Covariates (not used in main estimation).
- Time trend in productivity, i.e., learning by doing.
- Unobserved heterogeneity in taste for the job.
- Belief bias parameters.
- Miscellaneous.
====================================================
%}

%{
As discussed in section on Estimation and Identification,
some of the parameters seem primarily driven in straightforward
ways by simple features of the data.

What are the parameters to try different starting vals for?
~ Tau = scale parameter.
~ Theta1 and Theta2 = skill accumulation parameters.
~ mu1, mu2, mu3, puh13, puh23 = taste UH parameters.
%}


%% Baseline parameters.
%Baseline
if strcmp(baseline,'baseline')==1 && strcmp(beliefbias,'prior')==1
    NAMES = {'tau';'eta0';'sig_0';'sig_y'};
    STARTING = [22;19;3;7];
end

if strcmp(baseline,'baseline')==1 && strcmp(beliefbias,'no_bias')==1
    NAMES = {'tau';'eta0';'sig_0';'sig_y'};
    STARTING = [15;23;4;7];
end


%% Skill accumulation at outside option.
% First 5 weeks
if strcmp(first5,'first5')==1
    NAMES(end+1)={'v_ojt'};
    STARTING(end+1) = 0;
end

% Alternative time trend in outside option: Logit.
if strcmp(ootimetrend,'logit')==1 
    NAMES(end+1:end+2)={'theta1';'theta2'};
    STARTING(end+1:end+2) = [1 ; .1]; 
end


%% Time trend in productivity, i.e., learning by doing.
if strcmp(timetrend,'logit')==1 
    NAMES(end+1:end+2)={'a1';'a2'};
    STARTING(end+1:end+2) = [2;.1];
end


%% Unobserved heterogeneity in taste for the job.

% Three mass point UH in taste for the job.
if strcmp(op.tasteuh,'mp3')==1 
    NAMES(end+1:end+5)={'mu1';'mu2';'mu3';'puh13';'puh23'};
    if strcmp(tasteuhprobrestrict,'yes')==0
        STARTING(end+1:end+5)=[-3;-1;2;.5;.3]; 
    elseif strcmp(tasteuhprobrestrict,'yes')==1
        STARTING(end+1:end+5)=[-3;-1;1;log(.4/(1-.4));log(.4/(1-.4))];
    end
end

% Other forms of unobserved het in taste for job.
run zz_set_tasteuh_other.m;


%% Belief bias parameters.

% No belief bias
if strcmp(beliefbias,'no_bias')==1
    NAMES(end+1)={'sig_b'};
    STARTING(end+1) = [9];
end

% Constant mean shift in the prior
if strcmp(beliefbias,'prior')==1
    NAMES(end+1:end+2)={'eta_b';'sig_b'};
    STARTING(end+1:end+2) = [7;9];
end

% Other forms of unobserved het in belief bias.
run zz_set_beliefbias_other.m;

% Generalized learning (as opposed to Bayesian learning).
if strcmp(learnspeed,'general')==1 && strcmp(beliefbias,'prior')==1
    NAMES(end+1)={'sig_y_tilda'};
    STARTING(end+1)=[12];
end

if strcmp(learnspeed,'general')==1 && strcmp(beliefbias,'no_bias')==1
    NAMES(end+1)={'sig_y_tilda'};
    STARTING(end+1)=[33];
end

%% Miscellaneous.

% As part of the iteration used in estimating model with learning by doing,
% we set the starting values as below.
if strcmp(timetrend,'logit_firststage')==1
    STARTING= [paramhat(1:6);paramhat(9:end)];
end


if strcmp(learnspeed,'standard')==1 && strcmp(timetrend,'logit')==1    
    zz=load('Estimates/St_Vals/StdLearn_STVals.mat','paramhat');
    STARTING = zz.paramhat;
end


% Draw random starting values.
%stvals_rand;
%STARTING = ST_MAT(:,op.DrawNum); 

